//Kristen Kleckner - Capstone 2015
//Last updated May 10, 2015

#ifndef HEAP_H
#define HEAP_H

#include <iostream>
using namespace std;

const int DEFAULT_HEAP_SIZE = 10;

template <class ElementType>
class Heap
{
public:
	/********* Constructors and Destructors ************/
	Heap();
	Heap(int s);
	virtual ~Heap();

	/******** Accessors and Mutators *********/
	ElementType ExtractMax();
	void Insert(ElementType value, int index);
	int GetTotalElements();
	bool isEmpty() const;
	void Print() const;
private:
	int capacity;
	int heapSize;
	ElementType * heap;
};

//Default Constructor
template <class ElementType>
Heap<ElementType>::Heap()
{
	//using 10 for the default size
	heapSize = 0;
	capacity = DEFAULT_HEAP_SIZE;
	heap = new (nothrow) ElementType[DEFAULT_HEAP_SIZE];
}

//Constructor
template <class ElementType>
Heap<ElementType>::Heap(int s)
{
	//set to whatever size provided by user
	heapSize = 0;
	capacity = s;
	heap = new (nothrow) ElementType[s];
}

//Destructor
template <class ElementType>
Heap<ElementType>::~Heap()
{
	//delete the array
	delete [] heap;

	//reset heapSize and capacity to 0
	heapSize = 0;
	capacity = 0;
}

template <class ElementType>
ElementType Heap<ElementType>::ExtractMax()
{
	//if the heap size is 0, there is nothing to return
	if(heapSize == 0)
	{
		cout << "Heap is empty..." << endl;

		//create a default value to return since the function has to return a value
		ElementType x;
		return x;
	}

	//get the maximum value
	ElementType max = heap[1];

	//set the first value in the heap to the child
	heap[1] = heap[heapSize];

	//decrease the size
	heapSize--;

	//reorder the heap so that it is still a heap
	int index = 1;
	bool done = false;
	while(!done)
	{
		int left = 2*index;
		int right = 2*index+1;
		int largest = index;
		if(left <= heapSize && heap[left] > heap[index])
			largest = left;
		if(right <= heapSize && heap[right] > heap[largest])
			largest = right;
		if(largest != index)
		{
			swap(heap[index], heap[largest]);
			index = largest;
		}
		else
			done = true;
	}

	//return the maximum value
	return max;
}

template <class ElementType>
void Heap<ElementType>::Insert(ElementType value, int index)
{
	//if the heapsize is already at capacity
	//double the capacity
	//create a new heap, copy the data over, and delete the old heap
	if(heapSize == capacity -1)
	{
		capacity = capacity * 2;
		ElementType * newHeap = new (nothrow) ElementType[capacity];
		for(int i = 0; i <= heapSize; i++)
			newHeap[i] = heap[i];
		delete [] heap;
		heap = newHeap;
	}

	//increase the size
	heapSize++;

	//put the value at the last place in the heap
	heap[heapSize] = value;

	int child = heapSize;
	int parent = child/2;

	//reorder the heap so that it is still a heap
	while(parent >= 1 && heap[child] > heap[parent])
	{
		swap(heap[child], heap[parent]);
		child = parent;
		parent = child/2;
	}

	return;
}

template <class ElementType>
int Heap<ElementType>::GetTotalElements()
{
	//return the size of the heap
	return heapSize;
}

template <class ElementType>
bool Heap<ElementType>::isEmpty() const
{
	//check if the size of the heap is zero
	//return true if it's 0
	//return else otherwise
	if(heapSize == 0)
		return true;
	else
		return false;
}

template <class ElementType>
void Heap<ElementType>::Print() const
{
	//display all of the information stored in the heap
	for(int i = 1; i <= heapSize; i++)
	{
		cout << "Value at location: " << i << endl;
		cout << heap[i] << endl;
	}
}

#endif