﻿//Kristen Kleckner - Capstone 2015
//Last Modified May 10, 2015

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace testabc
{
    public partial class Form1 : Form
    {
        //Declare private variables unique to the form
        private Document myDoc;
        private int word_label_clicked = -1;
        private int hashtag_label_clicked = -1;
        private int user_label_clicked = -1;
        private int mention_label_clicked = -1;

        public Form1()
        {
            InitializeComponent();

            //Initialize the document class that will hold all of the data
            myDoc = new Document();
        }

        /************************
        Name: Form1_Load
        Purpose: Set the values of all of the labels used in the form
        ************************/
        private void Form1_Load(object sender, EventArgs e)
        {
            //Call the functions that will set all of the data in the document
            //These functions will open the files and store the data in the Document object
            //If something goes wrong on open, it will return -1
            //A message box will be displayed (in the function in the document class)
            //Then the program will close
            if (!myDoc.GetRetweetFileData())
                this.Close();
            if (!myDoc.GetFavoriteFileData())
                this.Close();
            if (!myDoc.GetWordFileData())
                this.Close();
            if (!myDoc.GetHashtagFileData())
                this.Close();
            if (!myDoc.GetMentionFileData())
                this.Close();
            if (!myDoc.GetUserFileData())
                this.Close();
            if (!myDoc.GetGeneralData())
                this.Close();

            //Set all of the text values for all of the labels
            SetGeneralData();
            SetRetweetData();
            SetFavoriteData();
            SetMentionsData();
            SetUserData();
            SetWordData();
            SetHashtagData();

            //Hide all of the word labels on each of the tabs
            //We want it set to the default when we first go to the tab
            HideAllWordLabels();
            HideAllHashtagLabels();
            HideAllUserLabels();
            HideAllMentionsLabels();

            //Hide all of the tweet labels since no word has been clicked on yet
            HideAllHashtagTweetLabels();
            HideAllWordTweetLabels();
            HideAllUserTweetLabels();
            HideAllMentionTweetLabels();
        }

        /************************
        Name: wordsUpDown_ValueChanged
        Purpose: Update the screen if the value in the 
            words numeric up down changed

        Similar Functions:
            hashtagUpDown_ValueChanged
            usersUpDown_ValueChanged
            mentionsUpDown_ValueChanged
        ************************/
        private void wordsUpDown_ValueChanged(object sender, EventArgs e)
        {
            //If word_label_clicked is set to -1
            //It means that no word has been clicked on
            //Therefore we can update the screen to show more circles
            if (word_label_clicked == -1)
            {
                //Hide all of the word labels, in case the value went down
                //This basically does a reset
                HideAllWordLabels();

                //Show all the word labels that need to be displayed
                ShowWordLabels();

                //update the circles
                this.Refresh();
            }
        }

        private void hashtagUpDown_ValueChanged(object sender, EventArgs e)
        {
            if (hashtag_label_clicked == -1)
            {
                HideAllHashtagLabels();
                ShowHashtagLabels();

                this.Refresh();
            }
        }

        private void usersUpDown_ValueChanged(object sender, EventArgs e)
        {
            if (user_label_clicked == -1)
            {
                HideAllUserLabels();
                ShowUserLabels();

                this.Refresh();
            }
        }

        private void mentionsUpDown_ValueChanged(object sender, EventArgs e)
        {
            if (mention_label_clicked == -1)
            {
                HideAllMentionsLabels();
                ShowMentionLabels();

                this.Refresh();
            }
        }

        /************************
        Name: topWordsTab_Paint
        Purpose: Draw the circles on the screen

        Similar Functions:
            topUsersTab_Paint
            topHashtagsTab_Paint
            topMentionsTab_Paint
        ************************/
        private void topWordsTab_Paint(object sender, PaintEventArgs e)
        {
            //Draw the light blue background circle
            e.Graphics.FillEllipse(Brushes.LightSkyBlue, 10, 10, 576, 576);

            //Draw the blue circles for the top five words
            //These will be drawn each time since the minimum number of words is 5
            e.Graphics.FillEllipse(Brushes.Blue, 213, 213, 130, 130);
            e.Graphics.FillEllipse(Brushes.Blue, 40, 215, 127, 127);
            e.Graphics.FillEllipse(Brushes.Blue, 110, 330, 124, 124);
            e.Graphics.FillEllipse(Brushes.Blue, 420, 180, 121, 121);
            e.Graphics.FillEllipse(Brushes.Blue, 260, 465, 118, 118);

            //Draw the rest of the blue circles as needed, based on the value of the wordsUpDown
            if (wordsUpDown.Value > 5)
                e.Graphics.FillEllipse(Brushes.Blue, 350, 290, 115, 115);
            if (wordsUpDown.Value > 6)
                e.Graphics.FillEllipse(Brushes.Blue, 200, 95, 112, 112);
            if (wordsUpDown.Value > 7)
                e.Graphics.FillEllipse(Brushes.Blue, 315, 135, 109, 109);
            if (wordsUpDown.Value > 8)
                e.Graphics.FillEllipse(Brushes.Blue, 75, 100, 106, 106);
            if (wordsUpDown.Value > 9)
                e.Graphics.FillEllipse(Brushes.Blue, 380, 425, 103, 103);

            //Note: Top words 11-15 are all the same size circle
            //When you get to this level, size doesn't matter as much
            //Additionally, we still want to have the circles be large enough to contain words
            if (wordsUpDown.Value > 10)
                e.Graphics.FillEllipse(Brushes.Blue, 240, 345, 100, 100);
            if (wordsUpDown.Value > 11)
                e.Graphics.FillEllipse(Brushes.Blue, 470, 320, 100, 100);
            if (wordsUpDown.Value > 12)
                e.Graphics.FillEllipse(Brushes.Blue, 145, 460, 100, 100);
            if (wordsUpDown.Value > 13)
                e.Graphics.FillEllipse(Brushes.Blue, 405, 75, 100, 100);
            if (wordsUpDown.Value > 14)
                e.Graphics.FillEllipse(Brushes.Blue, 280, 20, 100, 100);

            /*****************************************
            This series of if-else statements is used to determine which word was clicked.
            Then, based on what was clicked, it will draw the large red circle and display the 
            labels containing, the word that was clicked, its rank, and the number of times it was
            used, as well as the close label.  
            *****************************************/
            if (word_label_clicked == 1)
            {
                e.Graphics.FillEllipse(Brushes.Red, 148, 193, 250, 250);
                closeWordClickedLabel.Location = new Point(223, 393);
                wordClickedLabel.Text = "Word: " + topWord1Label.Text;
                wordClickedLabel.Location = new Point(198, 253);
                rankWordClickedLabel.Text = "Rank: 1";
                rankWordClickedLabel.Location = new Point(198, 286);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(198, 319);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 2)
            {
                e.Graphics.FillEllipse(Brushes.Red, 23, 193, 250, 250);
                closeWordClickedLabel.Location = new Point(98, 393);
                wordClickedLabel.Text = "Word: " + topWord2Label.Text;
                wordClickedLabel.Location = new Point(73, 253);
                rankWordClickedLabel.Text = "Rank: 2";
                rankWordClickedLabel.Location = new Point(73, 286);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(73, 319);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 3)
            {
                e.Graphics.FillEllipse(Brushes.Red, 45, 307, 250, 250);
                closeWordClickedLabel.Location = new Point(120, 507);
                wordClickedLabel.Text = "Word: " + topWord3Label.Text;
                wordClickedLabel.Location = new Point(105, 367);
                rankWordClickedLabel.Text = "Rank: 3";
                rankWordClickedLabel.Location = new Point(105, 400);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(105, 433);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 4)
            {
                e.Graphics.FillEllipse(Brushes.Red, 325, 155, 250, 250);
                closeWordClickedLabel.Location = new Point(400, 355);
                wordClickedLabel.Text = "Word: " + topWord4Label.Text;
                wordClickedLabel.Location = new Point(375, 215);
                rankWordClickedLabel.Text = "Rank: 4";
                rankWordClickedLabel.Location = new Point(375, 248);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(375, 281);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 5)
            {
                e.Graphics.FillEllipse(Brushes.Red, 195, 343, 250, 250);
                closeWordClickedLabel.Location = new Point(270, 543);
                wordClickedLabel.Text = "Word: " + topWord5Label.Text;
                wordClickedLabel.Location = new Point(245, 403);
                rankWordClickedLabel.Text = "Rank: 5";
                rankWordClickedLabel.Location = new Point(245, 436);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(245, 469);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 6)
            {
                e.Graphics.FillEllipse(Brushes.Red, 285, 263, 250, 250);
                closeWordClickedLabel.Location = new Point(360, 463);
                wordClickedLabel.Text = "Word: " + topWord6Label.Text;
                wordClickedLabel.Location = new Point(335, 323);
                rankWordClickedLabel.Text = "Rank: 6";
                rankWordClickedLabel.Location = new Point(335, 356);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(335, 389);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 7)
            {
                e.Graphics.FillEllipse(Brushes.Red, 135, 66, 250, 250);
                closeWordClickedLabel.Location = new Point(210, 266);
                wordClickedLabel.Text = "Word: " + topWord7Label.Text;
                wordClickedLabel.Location = new Point(185, 126);
                rankWordClickedLabel.Text = "Rank: 7";
                rankWordClickedLabel.Location = new Point(185, 159);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(185, 192);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 8)
            {
                e.Graphics.FillEllipse(Brushes.Red, 250, 104, 250, 250);
                closeWordClickedLabel.Location = new Point(325, 304);
                wordClickedLabel.Text = "Word: " + topWord8Label.Text;
                wordClickedLabel.Location = new Point(310, 164);
                rankWordClickedLabel.Text = "Rank: 8";
                rankWordClickedLabel.Location = new Point(310, 197);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(310, 230);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 9)
            {
                e.Graphics.FillEllipse(Brushes.Red, 70, 43, 250, 250);
                closeWordClickedLabel.Location = new Point(145, 243);
                wordClickedLabel.Text = "Word: " + topWord9Label.Text;
                wordClickedLabel.Location = new Point(120, 103);
                rankWordClickedLabel.Text = "Rank: 9";
                rankWordClickedLabel.Location = new Point(120, 136);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(120, 169);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 10)
            {
                e.Graphics.FillEllipse(Brushes.Red, 250, 316, 250, 250);
                closeWordClickedLabel.Location = new Point(325, 516);
                wordClickedLabel.Text = "Word: " + topWord10Label.Text;
                wordClickedLabel.Location = new Point(300, 376);
                rankWordClickedLabel.Text = "Rank: 10";
                rankWordClickedLabel.Location = new Point(300, 409);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(300, 442);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 11)
            {
                e.Graphics.FillEllipse(Brushes.Red, 175, 268, 250, 250);
                closeWordClickedLabel.Location = new Point(250, 468);
                wordClickedLabel.Text = "Word: " + topWord11Label.Text;
                wordClickedLabel.Location = new Point(225, 328);
                rankWordClickedLabel.Text = "Rank: 11";
                rankWordClickedLabel.Location = new Point(225, 361);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(225, 394);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 12)
            {
                e.Graphics.FillEllipse(Brushes.Red, 335, 250, 250, 250);
                closeWordClickedLabel.Location = new Point(410, 450);
                wordClickedLabel.Text = "Word: " + topWord12Label.Text;
                wordClickedLabel.Location = new Point(385, 310);
                rankWordClickedLabel.Text = "Rank: 12";
                rankWordClickedLabel.Location = new Point(385, 343);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(385, 376);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 13)
            {
                e.Graphics.FillEllipse(Brushes.Red, 80, 320, 250, 250);
                closeWordClickedLabel.Location = new Point(155, 520);
                wordClickedLabel.Text = "Word: " + topWord13Label.Text;
                wordClickedLabel.Location = new Point(130, 380);
                rankWordClickedLabel.Text = "Rank: 13";
                rankWordClickedLabel.Location = new Point(130, 413);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(130, 446);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 14)
            {
                e.Graphics.FillEllipse(Brushes.Red, 315, 40, 250, 250);
                closeWordClickedLabel.Location = new Point(380, 240);
                wordClickedLabel.Text = "Word: " + topWord15Label.Text;
                wordClickedLabel.Location = new Point(365, 100);
                rankWordClickedLabel.Text = "Rank: 14";
                rankWordClickedLabel.Location = new Point(365, 133);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(365, 166);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            else if (word_label_clicked == 15)
            {
                e.Graphics.FillEllipse(Brushes.Red, 190, 10, 250, 250);
                closeWordClickedLabel.Location = new Point(265, 210);
                wordClickedLabel.Text = "Word: " + topWord15Label.Text;
                wordClickedLabel.Location = new Point(250, 70);
                rankWordClickedLabel.Text = "Rank: 15";
                rankWordClickedLabel.Location = new Point(250, 103);
                usesWordClickedLabel.Text = "Uses: " + myDoc.Word_Uses.ToString();
                usesWordClickedLabel.Location = new Point(250, 136);
                closeWordClickedLabel.Visible = true;
                rankWordClickedLabel.Visible = true;
                usesWordClickedLabel.Visible = true;
                wordClickedLabel.Visible = true;
            }
            //If no word was clicked, just display the top five word labels
            else
            {
                topWord1Label.Visible = true;
                topWord2Label.Visible = true;
                topWord3Label.Visible = true;
                topWord4Label.Visible = true;
                topWord5Label.Visible = true;
            }
        }

        private void topHashtagTab_Paint(object sender, PaintEventArgs e)
        {
            e.Graphics.FillEllipse(Brushes.LightSkyBlue, 10, 10, 576, 576);

            e.Graphics.FillEllipse(Brushes.Blue, 213, 213, 130, 130);
            e.Graphics.FillEllipse(Brushes.Blue, 40, 215, 127, 127);
            e.Graphics.FillEllipse(Brushes.Blue, 110, 330, 124, 124);
            e.Graphics.FillEllipse(Brushes.Blue, 420, 180, 121, 121);
            e.Graphics.FillEllipse(Brushes.Blue, 260, 465, 118, 118);

            if (hashtagUpDown.Value > 5)
                e.Graphics.FillEllipse(Brushes.Blue, 350, 290, 115, 115);
            if (hashtagUpDown.Value > 6)
                e.Graphics.FillEllipse(Brushes.Blue, 200, 95, 112, 112);
            if (hashtagUpDown.Value > 7)
                e.Graphics.FillEllipse(Brushes.Blue, 315, 135, 109, 109);
            if (hashtagUpDown.Value > 8)
                e.Graphics.FillEllipse(Brushes.Blue, 75, 100, 106, 106);
            if (hashtagUpDown.Value > 9)
                e.Graphics.FillEllipse(Brushes.Blue, 380, 425, 103, 103);
            if (hashtagUpDown.Value > 10)
                e.Graphics.FillEllipse(Brushes.Blue, 240, 345, 100, 100);
            if (hashtagUpDown.Value > 11)
                e.Graphics.FillEllipse(Brushes.Blue, 470, 320, 100, 100);
            if (hashtagUpDown.Value > 12)
                e.Graphics.FillEllipse(Brushes.Blue, 145, 460, 100, 100);
            if (hashtagUpDown.Value > 13)
                e.Graphics.FillEllipse(Brushes.Blue, 405, 75, 100, 100);
            if (hashtagUpDown.Value > 14)
                e.Graphics.FillEllipse(Brushes.Blue, 280, 20, 100, 100);

            if (hashtag_label_clicked == 1)
            {
                e.Graphics.FillEllipse(Brushes.Red, 148, 193, 250, 250);
                closeHashtagClickedLabel.Location = new Point(223, 393);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag1Label.Text;
                hashtagClickedLabel.Location = new Point(178, 253);
                rankHashtagClickedLabel.Text = "Rank: 1";
                rankHashtagClickedLabel.Location = new Point(178, 286);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(178, 319);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 2)
            {
                e.Graphics.FillEllipse(Brushes.Red, 23, 193, 250, 250);
                closeHashtagClickedLabel.Location = new Point(98, 393);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag2Label.Text;
                hashtagClickedLabel.Location = new Point(53, 253);
                rankHashtagClickedLabel.Text = "Rank: 2";
                rankHashtagClickedLabel.Location = new Point(53, 286);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(53, 319);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 3)
            {
                e.Graphics.FillEllipse(Brushes.Red, 45, 307, 250, 250);
                closeHashtagClickedLabel.Location = new Point(120, 507);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag3Label.Text;
                hashtagClickedLabel.Location = new Point(85, 367);
                rankHashtagClickedLabel.Text = "Rank: 3";
                rankHashtagClickedLabel.Location = new Point(85, 400);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(85, 433);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 4)
            {
                e.Graphics.FillEllipse(Brushes.Red, 325, 155, 250, 250);
                closeHashtagClickedLabel.Location = new Point(400, 355);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag4Label.Text;
                hashtagClickedLabel.Location = new Point(355, 215);
                rankHashtagClickedLabel.Text = "Rank: 4";
                rankHashtagClickedLabel.Location = new Point(355, 248);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(355, 281);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 5)
            {
                e.Graphics.FillEllipse(Brushes.Red, 195, 343, 250, 250);
                closeHashtagClickedLabel.Location = new Point(270, 543);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag5Label.Text;
                hashtagClickedLabel.Location = new Point(225, 403);
                rankHashtagClickedLabel.Text = "Rank: 5";
                rankHashtagClickedLabel.Location = new Point(225, 436);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(225, 469);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 6)
            {
                e.Graphics.FillEllipse(Brushes.Red, 285, 263, 250, 250);
                closeHashtagClickedLabel.Location = new Point(360, 463);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag6Label.Text;
                hashtagClickedLabel.Location = new Point(315, 323);
                rankHashtagClickedLabel.Text = "Rank: 6";
                rankHashtagClickedLabel.Location = new Point(315, 356);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(315, 389);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 7)
            {
                e.Graphics.FillEllipse(Brushes.Red, 135, 66, 250, 250);
                closeHashtagClickedLabel.Location = new Point(210, 266);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag7Label.Text;
                hashtagClickedLabel.Location = new Point(165, 126);
                rankHashtagClickedLabel.Text = "Rank: 7";
                rankHashtagClickedLabel.Location = new Point(165, 159);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(165, 192);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 8)
            {
                e.Graphics.FillEllipse(Brushes.Red, 250, 104, 250, 250);
                closeHashtagClickedLabel.Location = new Point(325, 304);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag8Label.Text;
                hashtagClickedLabel.Location = new Point(290, 164);
                rankHashtagClickedLabel.Text = "Rank: 8";
                rankHashtagClickedLabel.Location = new Point(290, 197);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(290, 230);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 9)
            {
                e.Graphics.FillEllipse(Brushes.Red, 70, 43, 250, 250);
                closeHashtagClickedLabel.Location = new Point(145, 243);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag9Label.Text;
                hashtagClickedLabel.Location = new Point(100, 103);
                rankHashtagClickedLabel.Text = "Rank: 9";
                rankHashtagClickedLabel.Location = new Point(100, 136);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(100, 169);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 10)
            {
                e.Graphics.FillEllipse(Brushes.Red, 250, 316, 250, 250);
                closeHashtagClickedLabel.Location = new Point(325, 516);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag10Label.Text;
                hashtagClickedLabel.Location = new Point(280, 376);
                rankHashtagClickedLabel.Text = "Rank: 10";
                rankHashtagClickedLabel.Location = new Point(280, 409);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(280, 442);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 11)
            {
                e.Graphics.FillEllipse(Brushes.Red, 175, 268, 250, 250);
                closeHashtagClickedLabel.Location = new Point(250, 468);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag11Label.Text;
                hashtagClickedLabel.Location = new Point(205, 328);
                rankHashtagClickedLabel.Text = "Rank: 11";
                rankHashtagClickedLabel.Location = new Point(205, 361);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(205, 394);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 12)
            {
                e.Graphics.FillEllipse(Brushes.Red, 335, 250, 250, 250);
                closeHashtagClickedLabel.Location = new Point(410, 450);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag12Label.Text;
                hashtagClickedLabel.Location = new Point(365, 310);
                rankHashtagClickedLabel.Text = "Rank: 12";
                rankHashtagClickedLabel.Location = new Point(365, 343);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(365, 376);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 13)
            {
                e.Graphics.FillEllipse(Brushes.Red, 80, 320, 250, 250);
                closeHashtagClickedLabel.Location = new Point(155, 520);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag13Label.Text;
                hashtagClickedLabel.Location = new Point(110, 380);
                rankHashtagClickedLabel.Text = "Rank: 13";
                rankHashtagClickedLabel.Location = new Point(110, 413);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(110, 446);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 14)
            {
                e.Graphics.FillEllipse(Brushes.Red, 315, 40, 250, 250);
                closeHashtagClickedLabel.Location = new Point(380, 240);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag14Label.Text;
                hashtagClickedLabel.Location = new Point(345, 100);
                rankHashtagClickedLabel.Text = "Rank: 14";
                rankHashtagClickedLabel.Location = new Point(345, 133);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(345, 166);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }
            else if (hashtag_label_clicked == 15)
            {
                e.Graphics.FillEllipse(Brushes.Red, 190, 10, 250, 250);
                closeHashtagClickedLabel.Location = new Point(265, 210);
                hashtagClickedLabel.Text = "Hashtag: " + topHashtag15Label.Text;
                hashtagClickedLabel.Location = new Point(230, 70);
                rankHashtagClickedLabel.Text = "Rank: 15";
                rankHashtagClickedLabel.Location = new Point(230, 103);
                usesHashtagClickedLabel.Text = "Uses: " + myDoc.Hashtag_Uses.ToString();
                usesHashtagClickedLabel.Location = new Point(230, 136);
                closeHashtagClickedLabel.Visible = true;
                rankHashtagClickedLabel.Visible = true;
                usesHashtagClickedLabel.Visible = true;
                hashtagClickedLabel.Visible = true;
            }

            else
            {
                topHashtag1Label.Visible = true;
                topHashtag2Label.Visible = true;
                topHashtag3Label.Visible = true;
                topHashtag4Label.Visible = true;
                topHashtag5Label.Visible = true;
            }
        }
        private void topUsersTab_Paint(object sender, PaintEventArgs e)
        {

            {
                //draw this stuff regardless
                //background circle
                e.Graphics.FillEllipse(Brushes.LightSkyBlue, 10, 10, 576, 576);

                //circles for the other words
                e.Graphics.FillEllipse(Brushes.Blue, 213, 213, 130, 130);
                e.Graphics.FillEllipse(Brushes.Blue, 40, 215, 127, 127);
                e.Graphics.FillEllipse(Brushes.Blue, 110, 330, 124, 124);
                e.Graphics.FillEllipse(Brushes.Blue, 420, 180, 121, 121);
                e.Graphics.FillEllipse(Brushes.Blue, 260, 465, 118, 118);

                if (usersUpDown.Value > 5)
                    e.Graphics.FillEllipse(Brushes.Blue, 350, 290, 115, 115);
                if (usersUpDown.Value > 6)
                    e.Graphics.FillEllipse(Brushes.Blue, 200, 95, 112, 112);
                if (usersUpDown.Value > 7)
                    e.Graphics.FillEllipse(Brushes.Blue, 315, 135, 109, 109);
                if (usersUpDown.Value > 8)
                    e.Graphics.FillEllipse(Brushes.Blue, 75, 100, 106, 106);
                if (usersUpDown.Value > 9)
                    e.Graphics.FillEllipse(Brushes.Blue, 380, 425, 103, 103);

                //words 11-15 all have the same size circle just so the circles don't get too small
                if (usersUpDown.Value > 10)
                    e.Graphics.FillEllipse(Brushes.Blue, 240, 345, 100, 100);
                if (usersUpDown.Value > 11)
                    e.Graphics.FillEllipse(Brushes.Blue, 470, 320, 100, 100);
                if (usersUpDown.Value > 12)
                    e.Graphics.FillEllipse(Brushes.Blue, 145, 460, 100, 100);
                if (usersUpDown.Value > 13)
                    e.Graphics.FillEllipse(Brushes.Blue, 405, 75, 100, 100);
                if (usersUpDown.Value > 14)
                    e.Graphics.FillEllipse(Brushes.Blue, 280, 20, 100, 100);

                if (user_label_clicked == 1)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 148, 193, 250, 250);
                    closeUserClickedLabel.Location = new Point(223, 393);
                    userClickedLabel.Text = "User: " + topUser1Label.Text;
                    userClickedLabel.Location = new Point(178, 253);
                    rankUserClickedLabel.Text = "Rank: 1";
                    rankUserClickedLabel.Location = new Point(178, 286);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(178, 319);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 2)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 23, 193, 250, 250);
                    closeUserClickedLabel.Location = new Point(98, 393);
                    userClickedLabel.Text = "User: " + topUser2Label.Text;
                    userClickedLabel.Location = new Point(53, 253);
                    rankUserClickedLabel.Text = "Rank: 2";
                    rankUserClickedLabel.Location = new Point(53, 286);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(53, 319);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 3)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 45, 307, 250, 250);
                    closeUserClickedLabel.Location = new Point(120, 507);
                    userClickedLabel.Text = "User: " + topUser3Label.Text;
                    userClickedLabel.Location = new Point(85, 367);
                    rankUserClickedLabel.Text = "Rank: 3";
                    rankUserClickedLabel.Location = new Point(85, 400);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(85, 433);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 4)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 325, 155, 250, 250);
                    closeUserClickedLabel.Location = new Point(400, 355);
                    userClickedLabel.Text = "User: " + topUser4Label.Text;
                    userClickedLabel.Location = new Point(355, 215);
                    rankUserClickedLabel.Text = "Rank: 4";
                    rankUserClickedLabel.Location = new Point(355, 248);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(355, 281);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 5)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 195, 343, 250, 250);
                    closeUserClickedLabel.Location = new Point(270, 543);
                    userClickedLabel.Text = "User: " + topUser5Label.Text;
                    userClickedLabel.Location = new Point(225, 403);
                    rankUserClickedLabel.Text = "Rank: 5";
                    rankUserClickedLabel.Location = new Point(225, 436);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(225, 469);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 6)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 285, 263, 250, 250);
                    closeUserClickedLabel.Location = new Point(360, 463);
                    userClickedLabel.Text = "User: " + topUser6Label.Text;
                    userClickedLabel.Location = new Point(315, 323);
                    rankUserClickedLabel.Text = "Rank: 6";
                    rankUserClickedLabel.Location = new Point(315, 356);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(315, 389);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 7)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 135, 66, 250, 250);
                    closeUserClickedLabel.Location = new Point(210, 266);
                    userClickedLabel.Text = "User: " + topUser7Label.Text;
                    userClickedLabel.Location = new Point(165, 126);
                    rankUserClickedLabel.Text = "Rank: 7";
                    rankUserClickedLabel.Location = new Point(165, 159);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(165, 192);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 8)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 250, 104, 250, 250);
                    closeUserClickedLabel.Location = new Point(325, 304);
                    userClickedLabel.Text = "User: " + topUser8Label.Text;
                    userClickedLabel.Location = new Point(290, 164);
                    rankUserClickedLabel.Text = "Rank: 8";
                    rankUserClickedLabel.Location = new Point(290, 197);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(290, 230);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 9)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 70, 43, 250, 250);
                    closeUserClickedLabel.Location = new Point(145, 243);
                    userClickedLabel.Text = "User: " + topUser9Label.Text;
                    userClickedLabel.Location = new Point(100, 103);
                    rankUserClickedLabel.Text = "Rank: 9";
                    rankUserClickedLabel.Location = new Point(100, 136);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(100, 169);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 10)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 250, 316, 250, 250);
                    closeUserClickedLabel.Location = new Point(325, 516);
                    userClickedLabel.Text = "User: " + topUser10Label.Text;
                    userClickedLabel.Location = new Point(280, 376);
                    rankUserClickedLabel.Text = "Rank: 10";
                    rankUserClickedLabel.Location = new Point(280, 409);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(280, 442);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 11)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 175, 268, 250, 250);
                    closeUserClickedLabel.Location = new Point(250, 468);
                    userClickedLabel.Text = "User: " + topUser11Label.Text;
                    userClickedLabel.Location = new Point(205, 328);
                    rankUserClickedLabel.Text = "Rank: 11";
                    rankUserClickedLabel.Location = new Point(205, 361);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(205, 394);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 12)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 335, 250, 250, 250);
                    closeUserClickedLabel.Location = new Point(410, 450);
                    userClickedLabel.Text = "User: " + topUser12Label.Text;
                    userClickedLabel.Location = new Point(365, 310);
                    rankUserClickedLabel.Text = "Rank: 12";
                    rankUserClickedLabel.Location = new Point(365, 343);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(365, 376);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 13)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 80, 320, 250, 250);
                    closeUserClickedLabel.Location = new Point(155, 520);
                    userClickedLabel.Text = "User: " + topUser13Label.Text;
                    userClickedLabel.Location = new Point(110, 380);
                    rankUserClickedLabel.Text = "Rank: 13";
                    rankUserClickedLabel.Location = new Point(110, 413);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(110, 446);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 14)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 315, 40, 250, 250);
                    closeUserClickedLabel.Location = new Point(380, 240);
                    userClickedLabel.Text = "User: " + topUser14Label.Text;
                    userClickedLabel.Location = new Point(345, 100);
                    rankUserClickedLabel.Text = "Rank: 14";
                    rankUserClickedLabel.Location = new Point(345, 133);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(345, 166);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }
                else if (user_label_clicked == 15)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 190, 10, 250, 250);
                    closeUserClickedLabel.Location = new Point(265, 210);
                    userClickedLabel.Text = "User: " + topUser15Label.Text;
                    userClickedLabel.Location = new Point(230, 70);
                    rankUserClickedLabel.Text = "Rank: 15";
                    rankUserClickedLabel.Location = new Point(230, 103);
                    usesUserClickedLabel.Text = "Uses: " + myDoc.User_Uses.ToString();
                    usesUserClickedLabel.Location = new Point(230, 136);
                    closeUserClickedLabel.Visible = true;
                    rankUserClickedLabel.Visible = true;
                    usesUserClickedLabel.Visible = true;
                    userClickedLabel.Visible = true;
                }

                else
                {
                    topUser1Label.Visible = true;
                    topUser2Label.Visible = true;
                    topUser3Label.Visible = true;
                    topUser4Label.Visible = true;
                    topUser5Label.Visible = true;
                }
            }
        }
        private void topMentionsTab_Paint(object sender, PaintEventArgs e)
        {
            {
                e.Graphics.FillEllipse(Brushes.LightSkyBlue, 10, 10, 576, 576);

                e.Graphics.FillEllipse(Brushes.Blue, 213, 213, 130, 130);
                e.Graphics.FillEllipse(Brushes.Blue, 40, 215, 127, 127);
                e.Graphics.FillEllipse(Brushes.Blue, 110, 330, 124, 124);
                e.Graphics.FillEllipse(Brushes.Blue, 420, 180, 121, 121);
                e.Graphics.FillEllipse(Brushes.Blue, 260, 465, 118, 118);

                if (mentionsUpDown.Value > 5)
                    e.Graphics.FillEllipse(Brushes.Blue, 350, 290, 115, 115);
                if (mentionsUpDown.Value > 6)
                    e.Graphics.FillEllipse(Brushes.Blue, 200, 95, 112, 112);
                if (mentionsUpDown.Value > 7)
                    e.Graphics.FillEllipse(Brushes.Blue, 315, 135, 109, 109);
                if (mentionsUpDown.Value > 8)
                    e.Graphics.FillEllipse(Brushes.Blue, 75, 100, 106, 106);
                if (mentionsUpDown.Value > 9)
                    e.Graphics.FillEllipse(Brushes.Blue, 380, 425, 103, 103);
                if (mentionsUpDown.Value > 10)
                    e.Graphics.FillEllipse(Brushes.Blue, 240, 345, 100, 100);
                if (mentionsUpDown.Value > 11)
                    e.Graphics.FillEllipse(Brushes.Blue, 470, 320, 100, 100);
                if (mentionsUpDown.Value > 12)
                    e.Graphics.FillEllipse(Brushes.Blue, 145, 460, 100, 100);
                if (mentionsUpDown.Value > 13)
                    e.Graphics.FillEllipse(Brushes.Blue, 405, 75, 100, 100);
                if (mentionsUpDown.Value > 14)
                    e.Graphics.FillEllipse(Brushes.Blue, 280, 20, 100, 100);

                if (mention_label_clicked == 1)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 148, 193, 250, 250);
                    closeMentionClickedLabel.Location = new Point(223, 393);
                    mentionClickedLabel.Text = "User: " + topMentions1Label.Text;
                    mentionClickedLabel.Location = new Point(178, 253);
                    rankMentionClickedLabel.Text = "Rank: 1";
                    rankMentionClickedLabel.Location = new Point(178, 286);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(178, 319);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 2)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 23, 193, 250, 250);
                    closeMentionClickedLabel.Location = new Point(98, 393);
                    mentionClickedLabel.Text = "User: " + topMentions2Label.Text;
                    mentionClickedLabel.Location = new Point(53, 253);
                    rankMentionClickedLabel.Text = "Rank: 2";
                    rankMentionClickedLabel.Location = new Point(53, 286);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(53, 319);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 3)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 45, 307, 250, 250);
                    closeMentionClickedLabel.Location = new Point(120, 507);
                    mentionClickedLabel.Text = "User: " + topMentions3Label.Text;
                    mentionClickedLabel.Location = new Point(85, 367);
                    rankMentionClickedLabel.Text = "Rank: 3";
                    rankMentionClickedLabel.Location = new Point(85, 400);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(85, 433);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 4)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 325, 155, 250, 250);
                    closeMentionClickedLabel.Location = new Point(400, 355);
                    mentionClickedLabel.Text = "User: " + topMentions4Label.Text;
                    mentionClickedLabel.Location = new Point(355, 215);
                    rankMentionClickedLabel.Text = "Rank: 4";
                    rankMentionClickedLabel.Location = new Point(355, 248);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(355, 281);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 5)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 195, 343, 250, 250);
                    closeMentionClickedLabel.Location = new Point(270, 543);
                    mentionClickedLabel.Text = "User: " + topMentions5Label.Text;
                    mentionClickedLabel.Location = new Point(225, 403);
                    rankMentionClickedLabel.Text = "Rank: 5";
                    rankMentionClickedLabel.Location = new Point(225, 436);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(225, 469);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 6)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 285, 263, 250, 250);
                    closeMentionClickedLabel.Location = new Point(360, 463);
                    mentionClickedLabel.Text = "User: " + topMentions6Label.Text;
                    mentionClickedLabel.Location = new Point(315, 323);
                    rankMentionClickedLabel.Text = "Rank: 6";
                    rankMentionClickedLabel.Location = new Point(315, 356);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(315, 389);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 7)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 135, 66, 250, 250);
                    closeMentionClickedLabel.Location = new Point(210, 266);
                    mentionClickedLabel.Text = "User: " + topMentions7Label.Text;
                    mentionClickedLabel.Location = new Point(165, 126);
                    rankMentionClickedLabel.Text = "Rank: 7";
                    rankMentionClickedLabel.Location = new Point(165, 159);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(165, 192);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 8)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 250, 104, 250, 250);
                    closeMentionClickedLabel.Location = new Point(325, 304);
                    mentionClickedLabel.Text = "User: " + topMentions8Label.Text;
                    mentionClickedLabel.Location = new Point(290, 164);
                    rankMentionClickedLabel.Text = "Rank: 8";
                    rankMentionClickedLabel.Location = new Point(290, 197);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(290, 230);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 9)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 70, 43, 250, 250);
                    closeMentionClickedLabel.Location = new Point(145, 243);
                    mentionClickedLabel.Text = "User: " + topMentions9Label.Text;
                    mentionClickedLabel.Location = new Point(100, 103);
                    rankMentionClickedLabel.Text = "Rank: 9";
                    rankMentionClickedLabel.Location = new Point(100, 136);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(100, 169);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 10)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 250, 316, 250, 250);
                    closeMentionClickedLabel.Location = new Point(325, 516);
                    mentionClickedLabel.Text = "User: " + topMentions10Label.Text;
                    mentionClickedLabel.Location = new Point(280, 376);
                    rankMentionClickedLabel.Text = "Rank: 10";
                    rankMentionClickedLabel.Location = new Point(280, 409);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(280, 442);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 11)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 175, 268, 250, 250);
                    closeMentionClickedLabel.Location = new Point(250, 468);
                    mentionClickedLabel.Text = "User: " + topMentions11Label.Text;
                    mentionClickedLabel.Location = new Point(205, 328);
                    rankMentionClickedLabel.Text = "Rank: 11";
                    rankMentionClickedLabel.Location = new Point(205, 361);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(205, 394);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 12)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 335, 250, 250, 250);
                    closeMentionClickedLabel.Location = new Point(410, 450);
                    mentionClickedLabel.Text = "User: " + topMentions12Label.Text;
                    mentionClickedLabel.Location = new Point(365, 310);
                    rankMentionClickedLabel.Text = "Rank: 12";
                    rankMentionClickedLabel.Location = new Point(365, 343);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(365, 376);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 13)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 80, 320, 250, 250);
                    closeMentionClickedLabel.Location = new Point(155, 520);
                    mentionClickedLabel.Text = "User: " + topMentions13Label.Text;
                    mentionClickedLabel.Location = new Point(110, 380);
                    rankMentionClickedLabel.Text = "Rank: 13";
                    rankMentionClickedLabel.Location = new Point(110, 413);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(110, 446);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 14)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 315, 40, 250, 250);
                    closeMentionClickedLabel.Location = new Point(380, 240);
                    mentionClickedLabel.Text = "User: " + topMentions14Label.Text;
                    mentionClickedLabel.Location = new Point(345, 100);
                    rankMentionClickedLabel.Text = "Rank: 14";
                    rankMentionClickedLabel.Location = new Point(345, 133);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(345, 166);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }
                else if (mention_label_clicked == 15)
                {
                    e.Graphics.FillEllipse(Brushes.Red, 190, 10, 250, 250);
                    closeMentionClickedLabel.Location = new Point(265, 210);
                    mentionClickedLabel.Text = "User: " + topMentions15Label.Text;
                    mentionClickedLabel.Location = new Point(230, 70);
                    rankMentionClickedLabel.Text = "Rank: 15";
                    rankMentionClickedLabel.Location = new Point(230, 103);
                    usesMentionClickedLabel.Text = "Mentions: " + myDoc.Mention_Uses.ToString();
                    usesMentionClickedLabel.Location = new Point(230, 136);
                    closeMentionClickedLabel.Visible = true;
                    rankMentionClickedLabel.Visible = true;
                    usesMentionClickedLabel.Visible = true;
                    mentionClickedLabel.Visible = true;
                }

                else
                {
                    topMentions1Label.Visible = true;
                    topMentions2Label.Visible = true;
                    topMentions3Label.Visible = true;
                    topMentions4Label.Visible = true;
                    topMentions5Label.Visible = true;
                }
            }
        }

        /************************
        Name: topWord1Label_Click
        Purpose: Change the screen so that it will display the red circle,
            as well as information about the word that was clicked.  Display 
            tweets to give example of uses of that word

        Similar Functions:
            topWord2Label_Click, topWord3Label_Click, topWord4Label_Click,
            topWord5Label_Click, topWord6Label_Click, topWord7Label_Click,
            topWord8Label_Click, topWord9Label_Click, topWord10Label_Click,
            topWord11Label_Click, topWord12Label_Click, topWord13Label_Click,
            topWord14Label_Click, topWord15Label_Click, topHashtag1Label_Click,
            topHashtag2Label_Click, topHashtag3Label_Click, topHashtag4Label_Click,
            topHashtag5Label_Click, topHashtag6Label_Click, topHashtag7Label_Click,
            topHashtag8Label_Click, topHashtag9Label_Click, topHashtag10Label_Click,
            topHashtag1Label_Click, topHashtag12Label_Click, topHashtag13Label_Click,
            topHashtag14Label_Click, topHashtag15Label_Click, topUser1Label_Click,
            topUser2Label_Click, topUser3Label_Click, topUser4Label_Click, 
            topUser5Label_Click, topUser6Label_Click, topUser7Label_Click,
            topUser8Label_Click, topUser9Label_Click, topUser10Label_Click,
            topUser11Label_Click, topUser12Label_Click, topUser13Label_Click,
            topUser14Label_Click, topUser15Label_Click, topMention1Label_Click,
            topMention2Label_Click, topMention3Label_Click, topMention4Label_Click,
            topMention5Label_Click, topMention6Label_Click, topMention7Label_Click,
            topMention8Label_Click, topMention9Label_Click, topMention10Label_Click,
            topMention11Label_Click, topMention12Label_Click, topMention13Label_Click,
            topMention14Label_Click, topMention15Label_Click
        ************************/
        private void topWord1Label_Click(object sender, EventArgs e)
        {
            //Hide all the word labels so no other words can be 
            //clicked on until the red circle is closed
            HideAllWordLabels();

            //Set word_label_clicked to 1 to represent the top word
            word_label_clicked = 1;

            //Initialize an array of tweets to hold 15 examples of the word
            tweet[] word_tweets = new tweet[15];

            //Get random tweets 
            //If something went wrong, a message box was displayed in the
            //GetRandomWordTweets function.  Then close the application
            if (!myDoc.GetRandomWordTweets(topWord1Label.Text))
                this.Close();

            //Set the array of word tweets to be what was gathered in the call to GetRandomWordTweets
            word_tweets = myDoc.Word_Display_Tweets;

            //Set the maximum of the wordsTweetUpDown to however many tweets are in the array
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;

            //Invoke the Paint event to draw the circles
            Refresh();

            //Set all of the tweet labels
            SetWordTweetLabels(word_tweets);

            //Show the tweet labels
            ShowAllWordTweetLabels();
        }

        private void topWord2Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 2;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord2Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord3Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 3;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord3Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord4Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 4;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord4Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord5Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 5;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord5Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord6Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 6;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord6Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord7Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 7;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord7Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord8Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 8;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord8Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord9Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 9;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord9Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord10Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 10;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord10Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord11Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 11;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord11Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord12Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 12;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord12Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord13Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 13;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord13Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord14Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 14;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord14Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topWord15Label_Click(object sender, EventArgs e)
        {
            HideAllWordLabels();
            word_label_clicked = 15;

            tweet[] word_tweets = new tweet[15];
            if (!myDoc.GetRandomWordTweets(topWord15Label.Text))
                this.Close();
            word_tweets = myDoc.Word_Display_Tweets;
            wordsTweetUpDown.Maximum = myDoc.Max_Word_Tweets;
            Refresh();

            SetWordTweetLabels(word_tweets);
            ShowAllWordTweetLabels();
        }

        private void topHashtag1Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 1;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag1Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag2Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 2;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag2Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag3Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 3;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag3Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag4Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 4;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag4Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag5Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 5;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag5Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag6Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 6;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag6Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag7Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 7;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag7Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag8Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 8;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag8Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag9Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 9;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag9Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag10Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 1;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag10Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag11Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 11;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag11Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag12Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 12;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag12Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag13Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 13;

            tweet[] hashtag_tweets = new tweet[15];
            myDoc.GetRandomHashtagTweets(topHashtag13Label.Text);
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag14Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 14;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag14Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topHashtag15Label_Click(object sender, EventArgs e)
        {
            HideAllHashtagLabels();
            hashtag_label_clicked = 15;

            tweet[] hashtag_tweets = new tweet[15];
            if (!myDoc.GetRandomHashtagTweets(topHashtag15Label.Text))
                this.Close();
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;
            hashtagTweetUpDown.Maximum = myDoc.Max_Hashtag_Tweets;
            Refresh();

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void topMentions1Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 1;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions1Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions2Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 2;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions2Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions3Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 3;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions3Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions4Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 4;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions4Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions5Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 5;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions5Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions6Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 6;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions6Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions7Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 7;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions7Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions8Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 8;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions8Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions9Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 9;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions9Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions10Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 10;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions10Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions11Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 11;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions11Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions12Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 12;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions12Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions13Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 13;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions13Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions14Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 14;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions14Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topMentions15Label_Click(object sender, EventArgs e)
        {
            HideAllMentionsLabels();
            mention_label_clicked = 15;

            tweet[] mention_tweets = new tweet[15];
            if (!myDoc.GetRandomMentionTweets(topMentions15Label.Text))
                this.Close();
            mention_tweets = myDoc.Mention_Display_Tweets;
            mentionsTweetUpDown.Maximum = myDoc.Max_Mention_Tweets;
            Refresh();

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        private void topUser1Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 1;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser1Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser2Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 2;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser2Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser3Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 3;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser3Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser4Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 4;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser4Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser5Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 5;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser5Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser6Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 6;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser6Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser7Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 7;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser7Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser8Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 8;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser8Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser9Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 9;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser9Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser10Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 10;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser10Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser11Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 11;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser11Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser12Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 12;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser12Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser13Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 13;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser13Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser14Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 14;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser14Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void topUser15Label_Click(object sender, EventArgs e)
        {
            HideAllUserLabels();
            user_label_clicked = 15;

            tweet[] user_tweets = new tweet[15];
            if (!myDoc.GetRandomUserTweets(topUser15Label.Text))
                this.Close();
            user_tweets = myDoc.User_Display_Tweets;
            usersTweetUpDown.Maximum = myDoc.Max_User_Tweets;
            Refresh();

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        /***********************
        Name: closeWordClickedLabel_Click
        Purpose: Reset the tab to how it looked before the word was clicked

        Similar functions:
            closeHashtagClickedLabel_Click
            closeUserClickedLabel_Click
            closeMentionClickedLabel_Click
        ***********************/
        private void closeWordClickedLabel_Click(object sender, EventArgs e)
        {
            //Hide all of the labels on the red circle
            closeWordClickedLabel.Visible = false;
            rankWordClickedLabel.Visible = false;
            usesWordClickedLabel.Visible = false;
            wordClickedLabel.Visible = false;

            //Set word_label_clicked to -1 so no red circle will be drawn
            word_label_clicked = -1;

            //Invoke the Paint event
            Refresh();

            //Show the word labels
            ShowWordLabels();

            //Hide all of the tweet labels
            HideAllWordTweetLabels();
        }

        private void closeHashtagClickedLabel_Click(object sender, EventArgs e)
        {
            closeHashtagClickedLabel.Visible = false;
            rankHashtagClickedLabel.Visible = false;
            usesHashtagClickedLabel.Visible = false;
            hashtagClickedLabel.Visible = false;
            hashtag_label_clicked = -1;
            Refresh();
            ShowHashtagLabels();
            HideAllHashtagTweetLabels();
        }

        private void closeUserClickedLabel_Click(object sender, EventArgs e)
        {
            closeUserClickedLabel.Visible = false;
            rankUserClickedLabel.Visible = false;
            usesUserClickedLabel.Visible = false;
            userClickedLabel.Visible = false;
            user_label_clicked = -1;
            Refresh();
            ShowUserLabels();
            HideAllUserTweetLabels();
        }

        private void closeMentionClickedLabel_Click(object sender, EventArgs e)
        {
            closeMentionClickedLabel.Visible = false;
            rankMentionClickedLabel.Visible = false;
            usesMentionClickedLabel.Visible = false;
            mentionClickedLabel.Visible = false;
            mention_label_clicked = -1;
            Refresh();
            ShowMentionLabels();
            HideAllMentionTweetLabels();
        }

        /***********************
        Name: wordsTweetUpDown_ValueChanged
        Purpose: Change the number of tweets that are being displayed

        Similar functions:
            hashtagTweetUpDown_ValueChanged
            usersTweetUpDown_ValueChanged
            mentionsTweetUpDown_ValueChanged
        ***********************/
        private void wordsTweetUpDown_ValueChanged(object sender, EventArgs e)
        {
            //Hide all of the tweet labels
            //This is to ensure we hide tweets if the number decreased
            HideAllWordTweetLabels();

            //Make sure that a word is actually clicked and show the tweet labels
            if (word_label_clicked != -1)
                ShowAllWordTweetLabels();
        }

        private void hashtagTweetUpDown_ValueChanged(object sender, EventArgs e)
        {
            HideAllHashtagTweetLabels();
            if (hashtag_label_clicked != -1)
                ShowAllHashtagTweetLabels();
        }

        private void usersTweetUpDown_ValueChanged(object sender, EventArgs e)
        {
            HideAllHashtagTweetLabels();
            if (user_label_clicked != -1)
                ShowAllUserTweetLabels();
        }

        private void mentionsTweetUpDown_ValueChanged(object sender, EventArgs e)
        {
            HideAllMentionTweetLabels();
            if (mention_label_clicked != -1)
                ShowAllMentionTweetLabels();
        }

        /***********************
        Name: wordRefreshButton_Click
        Purpose: Display a new set of tweets for the word that was clicked

        Similar functions:
            hashtagRefreshButton_Click
            userRefreshButton_Click
            mentionRefreshButton_Click
        ***********************/
        private void wordRefreshButton_Click(object sender, EventArgs e)
        {
            //Determine which word label was clicked
            //Get random tweets for that word
            //If something goes wrong in GetRandomWordTweets, it will return -1
            //and display a message box.  We then need to close the appication
            if (word_label_clicked == 1)
            {
                if (!myDoc.GetRandomWordTweets(topWord1Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 2)
            {
                if (!myDoc.GetRandomWordTweets(topWord2Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 3)
            {
                if (!myDoc.GetRandomWordTweets(topWord3Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 4)
            {
                if (!myDoc.GetRandomWordTweets(topWord4Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 5)
            {
                if (!myDoc.GetRandomWordTweets(topWord5Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 6)
            {
                if (!myDoc.GetRandomWordTweets(topWord6Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 7)
            {
                if (!myDoc.GetRandomWordTweets(topWord7Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 8)
            {
                if (!myDoc.GetRandomWordTweets(topWord8Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 9)
            {
                if (!myDoc.GetRandomWordTweets(topWord9Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 10)
            {
                if (!myDoc.GetRandomWordTweets(topWord10Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 11)
            {
                if (!myDoc.GetRandomWordTweets(topWord11Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 12)
            {
                if (!myDoc.GetRandomWordTweets(topWord12Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 13)
            {
                if (!myDoc.GetRandomWordTweets(topWord13Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 14)
            {
                if (!myDoc.GetRandomWordTweets(topWord14Label.Text))
                    this.Close();
            }
            else if (word_label_clicked == 15)
            {
                if (!myDoc.GetRandomWordTweets(topWord15Label.Text))
                    this.Close();
            }
            else
                return;

            //Declare a new array of tweets
            tweet[] word_tweets = new tweet[15];

            //Set the array to the tweets chosen from GetRandomWordTweets
            word_tweets = myDoc.Word_Display_Tweets;

            //Set the text values of the tweet labels
            SetWordTweetLabels(word_tweets);

            //Show the tweet labels
            ShowAllWordTweetLabels();
        }

        private void hashtagRefreshButton_Click(object sender, EventArgs e)
        {
            if (hashtag_label_clicked == 1)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag1Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 2)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag2Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 3)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag3Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 4)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag4Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 5)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag5Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 6)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag6Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 7)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag7Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 8)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag8Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 9)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag9Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 10)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag10Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 11)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag11Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 12)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag12Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 13)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag13Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 14)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag14Label.Text))
                    this.Close();
            }
            else if (hashtag_label_clicked == 15)
            {
                if (!myDoc.GetRandomHashtagTweets(topHashtag15Label.Text))
                    this.Close();
            }
            else
                return;

            tweet[] hashtag_tweets = new tweet[15];
            hashtag_tweets = myDoc.Hashtag_Display_Tweets;

            SetHashtagTweetLabels(hashtag_tweets);
            ShowAllHashtagTweetLabels();
        }

        private void usersRefreshButton_Click(object sender, EventArgs e)
        {
            if (user_label_clicked == 1)
            {
                if (!myDoc.GetRandomUserTweets(topUser1Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 2)
            {
                if (!myDoc.GetRandomUserTweets(topUser2Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 3)
            {
                if (!myDoc.GetRandomUserTweets(topUser3Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 4)
            {
                if (!myDoc.GetRandomUserTweets(topUser4Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 5)
            {
                if (!myDoc.GetRandomUserTweets(topUser5Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 6)
            {
                if (!myDoc.GetRandomUserTweets(topUser6Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 7)
            {
                if (!myDoc.GetRandomUserTweets(topUser7Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 8)
            {
                if (!myDoc.GetRandomUserTweets(topUser8Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 9)
            {
                if (!myDoc.GetRandomUserTweets(topUser9Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 10)
            {
                if (!myDoc.GetRandomUserTweets(topUser10Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 11)
            {
                if (!myDoc.GetRandomUserTweets(topUser11Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 12)
            {
                if (!myDoc.GetRandomUserTweets(topUser12Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 13)
            {
                if (!myDoc.GetRandomUserTweets(topUser13Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 14)
            {
                if (!myDoc.GetRandomUserTweets(topUser14Label.Text))
                    this.Close();
            }
            else if (user_label_clicked == 15)
            {
                if (!myDoc.GetRandomUserTweets(topUser15Label.Text))
                    this.Close();
            }
            else
                return;

            tweet[] user_tweets = new tweet[15];
            user_tweets = myDoc.User_Display_Tweets;

            SetUserTweetLabels(user_tweets);
            ShowAllUserTweetLabels();
        }

        private void mentionsRefreshButton_Click(object sender, EventArgs e)
        {
            if (mention_label_clicked == 1)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions1Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 2)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions2Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 3)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions3Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 4)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions4Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 5)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions5Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 6)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions6Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 7)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions7Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 8)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions8Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 9)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions9Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 10)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions10Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 11)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions11Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 12)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions12Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 13)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions13Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 14)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions14Label.Text))
                    this.Close();
            }
            else if (mention_label_clicked == 15)
            {
                if (!myDoc.GetRandomMentionTweets(topMentions15Label.Text))
                    this.Close();
            }
            else
                return;

            tweet[] mention_tweets = new tweet[15];
            mention_tweets = myDoc.Mention_Display_Tweets;

            SetMentionTweetLabels(mention_tweets);
            ShowAllMentionTweetLabels();
        }

        /***********************
        Name: wordApplyButton_Click
        Purpose: Adjust the screen based on any new values in the numeric up downs

        Similar functions:
            hashtagApplyButton_Click
            userApplyButton_Click
            mentionApplyButton_Click
        ***********************/
        private void wordApplyButton_Click(object sender, EventArgs e)
        {
            //If a word was clicked, alter the number of tweets that are displayed
            if (word_label_clicked != -1)
            {
                ShowAllWordTweetLabels();
            }
            else
            {
                //Display the new number of words
                ShowWordLabels();

                //Hide all of the tweet labels
                HideAllWordTweetLabels();
            }

            //Invoke the paint event
            Refresh();
        }

        private void hashtagApplyButton_Click(object sender, EventArgs e)
        {
            if (hashtag_label_clicked != -1)
                ShowAllHashtagTweetLabels();
            else
            {
                ShowHashtagLabels();
                HideAllHashtagTweetLabels();
            }
            Refresh();
        }

        private void usersApplyButton_Click(object sender, EventArgs e)
        {
            if (user_label_clicked != -1)
                ShowAllUserTweetLabels();
            else
            {
                ShowUserLabels();
                HideAllUserTweetLabels();
            }
            Refresh();
        }

        private void mentionsApplyButton_Click(object sender, EventArgs e)
        {
            if (mention_label_clicked != -1)
                ShowAllMentionTweetLabels();
            else
            {
                ShowMentionLabels();
                HideAllMentionTweetLabels();
            }
            Refresh();
        }

        /***********************
        Name: wordResetButton_Click
        Purpose: Reset the tab to how it looks when the application first opens

        Similar functions:
            hashtagResetButton_Click
            userResetButton_Click
            mentionResetButton_Click
        ***********************/
        private void wordResetButton_Click(object sender, EventArgs e)
        {
            //Reset word_label_clicked to -1 so that no word will be selected
            word_label_clicked = -1;

            //Change the values of the numeric up downs to the minimum values
            wordsUpDown.Value = wordsUpDown.Minimum;
            wordsTweetUpDown.Value = wordsTweetUpDown.Minimum;

            //Show the word labels
            ShowWordLabels();

            //Hide any tweet labels
            HideAllWordTweetLabels();

            //Hide all of the labels that are associated with the red circle
            wordClickedLabel.Visible = false;
            rankWordClickedLabel.Visible = false;
            usesWordClickedLabel.Visible = false;
            closeWordClickedLabel.Visible = false;

            //Invoke the Paint event
            Refresh();
        }

        private void hashtagResetButton_Click(object sender, EventArgs e)
        {
            hashtag_label_clicked = -1;
            hashtagUpDown.Value = hashtagUpDown.Minimum;
            hashtagTweetUpDown.Value = hashtagTweetUpDown.Minimum;
            ShowHashtagLabels();
            hashtagClickedLabel.Visible = false;
            rankHashtagClickedLabel.Visible = false;
            usesHashtagClickedLabel.Visible = false;
            closeHashtagClickedLabel.Visible = false;
            HideAllHashtagTweetLabels();
        }

        private void userResetButton_Click(object sender, EventArgs e)
        {
            user_label_clicked = -1;
            usersUpDown.Value = usersUpDown.Minimum;
            usersTweetUpDown.Value = usersTweetUpDown.Minimum;
            ShowUserLabels();
            userClickedLabel.Visible = false;
            rankUserClickedLabel.Visible = false;
            usesUserClickedLabel.Visible = false;
            closeUserClickedLabel.Visible = false;
            HideAllUserTweetLabels();
        }

        private void mentionsResetButton_Click(object sender, EventArgs e)
        {
            mention_label_clicked = -1;
            mentionsUpDown.Value = mentionsUpDown.Minimum;
            mentionsTweetUpDown.Value = mentionsTweetUpDown.Minimum;
            ShowMentionLabels();
            userClickedLabel.Visible = false;
            rankUserClickedLabel.Visible = false;
            usesUserClickedLabel.Visible = false;
            closeUserClickedLabel.Visible = false;
            HideAllMentionTweetLabels();
        }

        /***********************
        Name: SetRetweetData
        Purpose: Get the retweets data from the Document and 
            change the labels so the tweets can be displayed

        Similar functions:
            SetFavoritesData
        ***********************/
        private void SetRetweetData()
        {
            //Declare a new array to hold all of the tweets
            tweet[] retweets = new tweet[15];

            //Set the array to the retweets array in the document
            retweets = myDoc.Retweets;

            //Set the values for the user who made the tweet
            //This is displayed on the General Stats tab
            rt1Label.Text = retweets[0].User;
            rt2Label.Text = retweets[1].User;
            rt3Label.Text = retweets[2].User;
            rt4Label.Text = retweets[3].User;
            rt5Label.Text = retweets[4].User;

            //Set the values for the number of retweets
            //This is displayed on the General Stats tab
            rtCount1Label.Text = retweets[0].Retweets.ToString();
            rtCount2Label.Text = retweets[1].Retweets.ToString();
            rtCount3Label.Text = retweets[2].Retweets.ToString();
            rtCount4Label.Text = retweets[3].Retweets.ToString();
            rtCount5Label.Text = retweets[4].Retweets.ToString();

            //Convert each tweet to the proper format
            //These are displayed on the Top Reweets tab
            topRT1Label.Text = ConvertRFTweetToLabel(retweets[0]);
            topRT2Label.Text = ConvertRFTweetToLabel(retweets[1]);
            topRT3Label.Text = ConvertRFTweetToLabel(retweets[2]);
            topRT4Label.Text = ConvertRFTweetToLabel(retweets[3]);
            topRT5Label.Text = ConvertRFTweetToLabel(retweets[4]);
            topRT6Label.Text = ConvertRFTweetToLabel(retweets[5]);
            topRT7Label.Text = ConvertRFTweetToLabel(retweets[6]);
            topRT8Label.Text = ConvertRFTweetToLabel(retweets[7]);
            topRT9Label.Text = ConvertRFTweetToLabel(retweets[8]);
            topRT10Label.Text = ConvertRFTweetToLabel(retweets[9]);
            topRT11Label.Text = ConvertRFTweetToLabel(retweets[10]);
            topRT12Label.Text = ConvertRFTweetToLabel(retweets[11]);
            topRT13Label.Text = ConvertRFTweetToLabel(retweets[12]);
            topRT14Label.Text = ConvertRFTweetToLabel(retweets[13]);
            topRT15Label.Text = ConvertRFTweetToLabel(retweets[14]);

            //Show all of the retweets
            ShowAllRetweetTweetLabels();
        }

        private void SetFavoriteData()
        {
            tweet[] favorites = new tweet[15];
            favorites = myDoc.Favorites;
            favorite1Label.Text = favorites[0].User;
            favorite2Label.Text = favorites[1].User;
            favorite3Label.Text = favorites[2].User;
            favorite4Label.Text = favorites[3].User;
            favorite5Label.Text = favorites[4].User;

            favoriteCount1Label.Text = favorites[0].Favorites.ToString();
            favoriteCount2Label.Text = favorites[1].Favorites.ToString();
            favoriteCount3Label.Text = favorites[2].Favorites.ToString();
            favoriteCount4Label.Text = favorites[3].Favorites.ToString();
            favoriteCount5Label.Text = favorites[4].Favorites.ToString();

            topFavorite1Label.Text = ConvertRFTweetToLabel(favorites[0]);
            topFavorite2Label.Text = ConvertRFTweetToLabel(favorites[1]);
            topFavorite3Label.Text = ConvertRFTweetToLabel(favorites[2]);
            topFavorite4Label.Text = ConvertRFTweetToLabel(favorites[3]);
            topFavorite5Label.Text = ConvertRFTweetToLabel(favorites[4]);
            topFavorite6Label.Text = ConvertRFTweetToLabel(favorites[5]);
            topFavorite7Label.Text = ConvertRFTweetToLabel(favorites[6]);
            topFavorite8Label.Text = ConvertRFTweetToLabel(favorites[7]);
            topFavorite9Label.Text = ConvertRFTweetToLabel(favorites[8]);
            topFavorite10Label.Text = ConvertRFTweetToLabel(favorites[9]);
            topFavorite11Label.Text = ConvertRFTweetToLabel(favorites[10]);
            topFavorite12Label.Text = ConvertRFTweetToLabel(favorites[11]);
            topFavorite13Label.Text = ConvertRFTweetToLabel(favorites[12]);
            topFavorite14Label.Text = ConvertRFTweetToLabel(favorites[13]);
            topFavorite15Label.Text = ConvertRFTweetToLabel(favorites[14]);

            ShowAllFavoriteTweetLabels();
        }

        /***********************
        Name: SetMentionsData
        Purpose: Set the labels pertaining to the mention data

        Similar functions:
            SetWordData
            SetUserData
            SetHashtagData
        ***********************/
        private void SetMentionsData()
        {
            //Declare an array to hold the mentions data
            word[] mentions = new word[15];

            //Set the array based on what's in the document object
            mentions = myDoc.Top_Mentions;

            //Set the user labels on the General Stats tab
            mentions1Label.Text = mentions[0].Text;
            mentions2Label.Text = mentions[1].Text;
            mentions3Label.Text = mentions[2].Text;
            mentions4Label.Text = mentions[3].Text;
            mentions5Label.Text = mentions[4].Text;

            //Set the count labels on the General Stats tab
            mentionsCount1Label.Text = mentions[0].Count.ToString();
            mentionsCount2Label.Text = mentions[1].Count.ToString();
            mentionsCount3Label.Text = mentions[2].Count.ToString();
            mentionsCount4Label.Text = mentions[3].Count.ToString();
            mentionsCount5Label.Text = mentions[4].Count.ToString();

            //Set the labels for the blue circles on the Top Mentions tab
            topMentions1Label.Text = mentions[0].Text;
            topMentions2Label.Text = mentions[1].Text;
            topMentions3Label.Text = mentions[2].Text;
            topMentions4Label.Text = mentions[3].Text;
            topMentions5Label.Text = mentions[4].Text;
            topMentions6Label.Text = mentions[5].Text;
            topMentions7Label.Text = mentions[6].Text;
            topMentions8Label.Text = mentions[7].Text;
            topMentions9Label.Text = mentions[8].Text;
            topMentions10Label.Text = mentions[9].Text;
            topMentions11Label.Text = mentions[10].Text;
            topMentions12Label.Text = mentions[11].Text;
            topMentions13Label.Text = mentions[12].Text;
            topMentions14Label.Text = mentions[13].Text;
            topMentions15Label.Text = mentions[14].Text;
        }

        private void SetUserData()
        {
            word[] users = new word[15];
            users = myDoc.Top_Users;
            user1Label.Text = users[0].Text;
            user2Label.Text = users[1].Text;
            user3Label.Text = users[2].Text;
            user4Label.Text = users[3].Text;
            user5Label.Text = users[4].Text;

            userCount1Label.Text = users[0].Count.ToString();
            userCount2Label.Text = users[1].Count.ToString();
            userCount3Label.Text = users[2].Count.ToString();
            userCount4Label.Text = users[3].Count.ToString();
            userCount5Label.Text = users[4].Count.ToString();

            topUser1Label.Text = users[0].Text;
            topUser2Label.Text = users[1].Text;
            topUser3Label.Text = users[2].Text;
            topUser4Label.Text = users[3].Text;
            topUser5Label.Text = users[4].Text;
            topUser6Label.Text = users[5].Text;
            topUser7Label.Text = users[6].Text;
            topUser8Label.Text = users[7].Text;
            topUser9Label.Text = users[8].Text;
            topUser10Label.Text = users[9].Text;
            topUser11Label.Text = users[10].Text;
            topUser12Label.Text = users[11].Text;
            topUser13Label.Text = users[12].Text;
            topUser14Label.Text = users[13].Text;
            topUser15Label.Text = users[14].Text;
        }

        private void SetWordData()
        {
            word[] words = new word[15];
            words = myDoc.Top_Words;
            word1Label.Text = words[0].Text;
            word2Label.Text = words[1].Text;
            word3Label.Text = words[2].Text;
            word4Label.Text = words[3].Text;
            word5Label.Text = words[4].Text;

            wordCount1Label.Text = words[0].Count.ToString();
            wordCount2Label.Text = words[1].Count.ToString();
            wordCount3Label.Text = words[2].Count.ToString();
            wordCount4Label.Text = words[3].Count.ToString();
            wordCount5Label.Text = words[4].Count.ToString();

            topWord1Label.Text = words[0].Text;
            topWord2Label.Text = words[1].Text;
            topWord3Label.Text = words[2].Text;
            topWord4Label.Text = words[3].Text;
            topWord5Label.Text = words[4].Text;
            topWord6Label.Text = words[5].Text;
            topWord7Label.Text = words[6].Text;
            topWord8Label.Text = words[7].Text;
            topWord9Label.Text = words[8].Text;
            topWord10Label.Text = words[9].Text;
            topWord11Label.Text = words[10].Text;
            topWord12Label.Text = words[11].Text;
            topWord13Label.Text = words[12].Text;
            topWord14Label.Text = words[13].Text;
            topWord15Label.Text = words[14].Text;
        }

        private void SetHashtagData()
        {
            word[] hashtags = new word[15];
            hashtags = myDoc.Top_Hashtags;
            hashtag1Label.Text = hashtags[0].Text;
            hashtag2Label.Text = hashtags[1].Text;
            hashtag3Label.Text = hashtags[2].Text;
            hashtag4Label.Text = hashtags[3].Text;
            hashtag5Label.Text = hashtags[4].Text;

            hashtagCount1Label.Text = hashtags[0].Count.ToString();
            hashtagCount2Label.Text = hashtags[1].Count.ToString();
            hashtagCount3Label.Text = hashtags[2].Count.ToString();
            hashtagCount4Label.Text = hashtags[3].Count.ToString();
            hashtagCount5Label.Text = hashtags[4].Count.ToString();

            topHashtag1Label.Text = hashtags[0].Text;
            topHashtag2Label.Text = hashtags[1].Text;
            topHashtag3Label.Text = hashtags[2].Text;
            topHashtag4Label.Text = hashtags[3].Text;
            topHashtag5Label.Text = hashtags[4].Text;
            topHashtag6Label.Text = hashtags[5].Text;
            topHashtag7Label.Text = hashtags[6].Text;
            topHashtag8Label.Text = hashtags[7].Text;
            topHashtag9Label.Text = hashtags[8].Text;
            topHashtag10Label.Text = hashtags[9].Text;
            topHashtag11Label.Text = hashtags[10].Text;
            topHashtag12Label.Text = hashtags[11].Text;
            topHashtag13Label.Text = hashtags[12].Text;
            topHashtag14Label.Text = hashtags[13].Text;
            topHashtag15Label.Text = hashtags[14].Text;
        }

        /***********************
        Name: SetGeneralData
        Purpose: Set the General information panel on teh General Stats page. 
            All of this information is read in from a file and is stored in the 
            Document object
        ***********************/
        private void SetGeneralData()
        {
            keywordLabel.Text = myDoc.Searched_On;
            totalTweetsLabel.Text = myDoc.Total_Tweets;
            uniqueUsersLabel.Text = myDoc.Total_Users;
            earliestTweetLabel.Text = myDoc.Earliest_Date;
            latestTweetLabel.Text = myDoc.Latest_Date;
            totalWordsLabel.Text = myDoc.Total_Words;
            totalHashtagsLabel.Text = myDoc.Total_Hashtags;
            totalMentionsLabel.Text = myDoc.Total_Mentions;
        }

        /***********************
        Name: HideAllWordLabels
        Purpose: Make all of the word labels in the blue circles not visible

        Similar functions:
            HideAllHashtagLabels
            HideAllUserLabels
            HideAllMentionsLabels
        ***********************/
        private void HideAllWordLabels()
        {
            topWord1Label.Visible = false;
            topWord2Label.Visible = false;
            topWord3Label.Visible = false;
            topWord4Label.Visible = false;
            topWord5Label.Visible = false;
            topWord6Label.Visible = false;
            topWord7Label.Visible = false;
            topWord8Label.Visible = false;
            topWord9Label.Visible = false;
            topWord10Label.Visible = false;
            topWord11Label.Visible = false;
            topWord12Label.Visible = false;
            topWord13Label.Visible = false;
            topWord14Label.Visible = false;
            topWord15Label.Visible = false;
        }

        private void HideAllHashtagLabels()
        {
            topHashtag1Label.Visible = false;
            topHashtag2Label.Visible = false;
            topHashtag3Label.Visible = false;
            topHashtag4Label.Visible = false;
            topHashtag5Label.Visible = false;
            topHashtag6Label.Visible = false;
            topHashtag7Label.Visible = false;
            topHashtag8Label.Visible = false;
            topHashtag9Label.Visible = false;
            topHashtag10Label.Visible = false;
            topHashtag11Label.Visible = false;
            topHashtag12Label.Visible = false;
            topHashtag13Label.Visible = false;
            topHashtag14Label.Visible = false;
            topHashtag15Label.Visible = false;
        }

        private void HideAllUserLabels()
        {
            topUser1Label.Visible = false;
            topUser2Label.Visible = false;
            topUser3Label.Visible = false;
            topUser4Label.Visible = false;
            topUser5Label.Visible = false;
            topUser6Label.Visible = false;
            topUser7Label.Visible = false;
            topUser8Label.Visible = false;
            topUser9Label.Visible = false;
            topUser10Label.Visible = false;
            topUser11Label.Visible = false;
            topUser12Label.Visible = false;
            topUser13Label.Visible = false;
            topUser14Label.Visible = false;
            topUser15Label.Visible = false;
        }

        private void HideAllMentionsLabels()
        {
            topMentions1Label.Visible = false;
            topMentions2Label.Visible = false;
            topMentions3Label.Visible = false;
            topMentions4Label.Visible = false;
            topMentions5Label.Visible = false;
            topMentions6Label.Visible = false;
            topMentions7Label.Visible = false;
            topMentions8Label.Visible = false;
            topMentions9Label.Visible = false;
            topMentions10Label.Visible = false;
            topMentions11Label.Visible = false;
            topMentions12Label.Visible = false;
            topMentions13Label.Visible = false;
            topMentions14Label.Visible = false;
            topMentions15Label.Visible = false;
        }

        /***********************
        Name: HideAllWordTweetLabels
        Purpose: Set all of the tweet labels to be not visible

        Similar functions:
            HideAllHashtagTweetLabels
            HideAllUserTweetLabels
            HideAllMentionTweetLabels
        ***********************/
        private void HideAllWordTweetLabels()
        {
            wordTweet1Label.Visible = false;
            wordTweet2Label.Visible = false;
            wordTweet3Label.Visible = false;
            wordTweet4Label.Visible = false;
            wordTweet5Label.Visible = false;
            wordTweet6Label.Visible = false;
            wordTweet7Label.Visible = false;
            wordTweet8Label.Visible = false;
            wordTweet9Label.Visible = false;
            wordTweet10Label.Visible = false;
            wordTweet11Label.Visible = false;
            wordTweet12Label.Visible = false;
            wordTweet13Label.Visible = false;
            wordTweet14Label.Visible = false;
            wordTweet15Label.Visible = false;
        }

        private void HideAllHashtagTweetLabels()
        {
            hashtagTweet1Label.Visible = false;
            hashtagTweet2Label.Visible = false;
            hashtagTweet3Label.Visible = false;
            hashtagTweet4Label.Visible = false;
            hashtagTweet5Label.Visible = false;
            hashtagTweet6Label.Visible = false;
            hashtagTweet7Label.Visible = false;
            hashtagTweet8Label.Visible = false;
            hashtagTweet9Label.Visible = false;
            hashtagTweet10Label.Visible = false;
            hashtagTweet11Label.Visible = false;
            hashtagTweet12Label.Visible = false;
            hashtagTweet13Label.Visible = false;
            hashtagTweet14Label.Visible = false;
            hashtagTweet15Label.Visible = false;
        }

        private void HideAllUserTweetLabels()
        {
            userTweet1Label.Visible = false;
            userTweet2Label.Visible = false;
            userTweet3Label.Visible = false;
            userTweet4Label.Visible = false;
            userTweet5Label.Visible = false;
            userTweet6Label.Visible = false;
            userTweet7Label.Visible = false;
            userTweet8Label.Visible = false;
            userTweet9Label.Visible = false;
            userTweet10Label.Visible = false;
            userTweet11Label.Visible = false;
            userTweet12Label.Visible = false;
            userTweet13Label.Visible = false;
            userTweet14Label.Visible = false;
            userTweet15Label.Visible = false;
        }

        private void HideAllMentionTweetLabels()
        {
            mentionsTweet1Label.Visible = false;
            mentionsTweet2Label.Visible = false;
            mentionsTweet3Label.Visible = false;
            mentionsTweet4Label.Visible = false;
            mentionsTweet5Label.Visible = false;
            mentionsTweet6Label.Visible = false;
            mentionsTweet7Label.Visible = false;
            mentionsTweet8Label.Visible = false;
            mentionsTweet9Label.Visible = false;
            mentionsTweet10Label.Visible = false;
            mentionsTweet11Label.Visible = false;
            mentionsTweet12Label.Visible = false;
            mentionsTweet13Label.Visible = false;
            mentionsTweet14Label.Visible = false;
            mentionsTweet15Label.Visible = false;
        }

        /***********************
        Name: ConvertTweetToLabel
        Parameters: a tweet
        Returns: a string based off the tweet
        Purpose: Take a tweet object and convert it into a string
            so that it can be displayed in a label.
        ***********************/
        private string ConvertTweetToLabel(tweet x)
        {
            //As a back up, replace any line breaks
            x.Text.Replace("/n", "");

            //If a tweet is more than 70 characters
            //Break it up into two lines
            if (x.Text.Length > 70)
            {
                //Create an array of strings that is composed of
                //the tweet text split on spaces
                string[] tweet = x.Text.Split(' ');

                //Declare variables that will help us create the string
                string line = "";
                int char_count = 0;
                int split_at = 0;

                //Run through each index of the tweet array, counting each character
                //Once we are larger than 70, break
                //Make sure to save i-1 as the index on where we need to split
                for (int i = 0; i < tweet.Length; i++)
                {
                    if (char_count > 70)
                    {
                        split_at = i - 1;
                        break;
                    }
                    char_count += tweet[i].Length + 1;    //add one for the space between characters
                }

                //Run through each index of the tweet array adding each word and a space
                //to the variable line.  When we hit the index we found in the previous for loop
                //Add a new line and continue adding words
                for (int i = 0; i < tweet.Length; i++)
                {
                    if (i != split_at)
                    {
                        line += tweet[i] + " ";
                    }
                    else
                    {
                        line += Environment.NewLine + tweet[i] + " ";
                    }
                }

                //Return the formatted string
                return line + Environment.NewLine + "     " + x.User + " at " + x.Date + " RT: " + x.Retweets.ToString() + " Fav: " + x.Favorites.ToString();
            }
            //If the tweet is less than 70 characters, we don't need to split
            //it into two lines and can just return the formatted string
            else
                return x.Text + Environment.NewLine + "     " + x.User + " at " + x.Date + " RT: " + x.Retweets.ToString() + " Fav: " + x.Favorites.ToString();
        }

        /***********************
        Name: ConvertRFTweetToLabel
        Parameters: a tweet
        Returns: a string based off that tweet
        Purpose: Convert a tweet to a string so it can be displayed as a label
        ***********************/
        private string ConvertRFTweetToLabel(tweet x)
        {
            return x.Text + Environment.NewLine + "     " + x.User + " at " + x.Date + " RT: " + x.Retweets.ToString() + " Fav: " + x.Favorites.ToString();
        }

        /***********************
        Name: ShowAllWordTweetLabels
        Purpose: Set the locations of the tweet labels and display them

        Similar functions:
            ShowAllHashtagTweetLabels
            ShowAllUserTweetLabels
            ShowAllMentionTweetLabels
        ***********************/
        private void ShowAllWordTweetLabels()
        {
            //Set the location for each tweet label
            //They will all be veritically aligned
            //Each tweet's Y coordinate is calculated based on where the tweet above
            //it was positioned, the height of the tweet above it, and a little bit 
            //of extra space so things don't run together
            wordTweet1Label.Location = new Point(650, 0);
            wordTweet2Label.Location = new Point(650, wordTweet1Label.Location.Y + wordTweet1Label.Height + 5);
            wordTweet3Label.Location = new Point(650, wordTweet2Label.Location.Y + wordTweet2Label.Height + 5);
            wordTweet4Label.Location = new Point(650, wordTweet3Label.Location.Y + wordTweet3Label.Height + 5);
            wordTweet5Label.Location = new Point(650, wordTweet4Label.Location.Y + wordTweet4Label.Height + 5);
            wordTweet6Label.Location = new Point(650, wordTweet5Label.Location.Y + wordTweet5Label.Height + 5);
            wordTweet7Label.Location = new Point(650, wordTweet6Label.Location.Y + wordTweet6Label.Height + 5);
            wordTweet8Label.Location = new Point(650, wordTweet7Label.Location.Y + wordTweet7Label.Height + 5);
            wordTweet9Label.Location = new Point(650, wordTweet8Label.Location.Y + wordTweet8Label.Height + 5);
            wordTweet10Label.Location = new Point(650, wordTweet9Label.Location.Y + wordTweet9Label.Height + 5);
            wordTweet11Label.Location = new Point(650, wordTweet10Label.Location.Y + wordTweet10Label.Height + 5);
            wordTweet12Label.Location = new Point(650, wordTweet11Label.Location.Y + wordTweet11Label.Height + 5);
            wordTweet13Label.Location = new Point(650, wordTweet12Label.Location.Y + wordTweet12Label.Height + 5);
            wordTweet14Label.Location = new Point(650, wordTweet13Label.Location.Y + wordTweet13Label.Height + 5);
            wordTweet15Label.Location = new Point(650, wordTweet14Label.Location.Y + wordTweet14Label.Height + 5);

            //We will always have to show 5 since that's the minimum value
            wordTweet1Label.Visible = true;
            wordTweet2Label.Visible = true;
            wordTweet3Label.Visible = true;
            wordTweet4Label.Visible = true;
            wordTweet5Label.Visible = true;

            //Display other tweets based on the value of the tweets numeric up down
            if (wordsTweetUpDown.Value > 5)
                wordTweet6Label.Visible = true;
            if (wordsTweetUpDown.Value > 6)
                wordTweet7Label.Visible = true;
            if (wordsTweetUpDown.Value > 7)
                wordTweet8Label.Visible = true;
            if (wordsTweetUpDown.Value > 8)
                wordTweet9Label.Visible = true;
            if (wordsTweetUpDown.Value > 9)
                wordTweet10Label.Visible = true;
            if (wordsTweetUpDown.Value > 10)
                wordTweet11Label.Visible = true;
            if (wordsTweetUpDown.Value > 11)
                wordTweet12Label.Visible = true;
            if (wordsTweetUpDown.Value > 12)
                wordTweet13Label.Visible = true;
            if (wordsTweetUpDown.Value > 13)
                wordTweet14Label.Visible = true;
            if (wordsTweetUpDown.Value > 14)
                wordTweet15Label.Visible = true;
        }

        private void ShowAllHashtagTweetLabels()
        {
            hashtagTweet1Label.Location = new Point(650, 0);
            hashtagTweet2Label.Location = new Point(650, hashtagTweet1Label.Location.Y + hashtagTweet1Label.Height + 5);
            hashtagTweet3Label.Location = new Point(650, hashtagTweet2Label.Location.Y + hashtagTweet2Label.Height + 5);
            hashtagTweet4Label.Location = new Point(650, hashtagTweet3Label.Location.Y + hashtagTweet3Label.Height + 5);
            hashtagTweet5Label.Location = new Point(650, hashtagTweet4Label.Location.Y + hashtagTweet4Label.Height + 5);
            hashtagTweet6Label.Location = new Point(650, hashtagTweet5Label.Location.Y + hashtagTweet5Label.Height + 5);
            hashtagTweet7Label.Location = new Point(650, hashtagTweet6Label.Location.Y + hashtagTweet6Label.Height + 5);
            hashtagTweet8Label.Location = new Point(650, hashtagTweet7Label.Location.Y + hashtagTweet7Label.Height + 5);
            hashtagTweet9Label.Location = new Point(650, hashtagTweet8Label.Location.Y + hashtagTweet8Label.Height + 5);
            hashtagTweet10Label.Location = new Point(650, hashtagTweet9Label.Location.Y + hashtagTweet9Label.Height + 5);
            hashtagTweet11Label.Location = new Point(650, hashtagTweet10Label.Location.Y + hashtagTweet10Label.Height + 5);
            hashtagTweet12Label.Location = new Point(650, hashtagTweet11Label.Location.Y + hashtagTweet11Label.Height + 5);
            hashtagTweet13Label.Location = new Point(650, hashtagTweet12Label.Location.Y + hashtagTweet12Label.Height + 5);
            hashtagTweet14Label.Location = new Point(650, hashtagTweet13Label.Location.Y + hashtagTweet13Label.Height + 5);
            hashtagTweet15Label.Location = new Point(650, hashtagTweet14Label.Location.Y + hashtagTweet14Label.Height + 5);

            hashtagTweet1Label.Visible = true;
            hashtagTweet2Label.Visible = true;
            hashtagTweet3Label.Visible = true;
            hashtagTweet4Label.Visible = true;
            hashtagTweet5Label.Visible = true;
            if (hashtagTweetUpDown.Value > 5)
                hashtagTweet6Label.Visible = true;
            if (hashtagTweetUpDown.Value > 6)
                hashtagTweet7Label.Visible = true;
            if (hashtagTweetUpDown.Value > 7)
                hashtagTweet8Label.Visible = true;
            if (hashtagTweetUpDown.Value > 8)
                hashtagTweet9Label.Visible = true;
            if (hashtagTweetUpDown.Value > 9)
                hashtagTweet10Label.Visible = true;
            if (hashtagTweetUpDown.Value > 10)
                hashtagTweet11Label.Visible = true;
            if (hashtagTweetUpDown.Value > 11)
                hashtagTweet12Label.Visible = true;
            if (hashtagTweetUpDown.Value > 12)
                hashtagTweet13Label.Visible = true;
            if (hashtagTweetUpDown.Value > 13)
                hashtagTweet14Label.Visible = true;
            if (hashtagTweetUpDown.Value > 14)
                hashtagTweet15Label.Visible = true;
        }

        private void ShowAllUserTweetLabels()
        {
            userTweet1Label.Location = new Point(650, 0);
            userTweet2Label.Location = new Point(650, userTweet1Label.Location.Y + userTweet1Label.Height + 5);
            userTweet3Label.Location = new Point(650, userTweet2Label.Location.Y + userTweet2Label.Height + 5);
            userTweet4Label.Location = new Point(650, userTweet3Label.Location.Y + userTweet3Label.Height + 5);
            userTweet5Label.Location = new Point(650, userTweet4Label.Location.Y + userTweet4Label.Height + 5);
            userTweet6Label.Location = new Point(650, userTweet5Label.Location.Y + userTweet5Label.Height + 5);
            userTweet7Label.Location = new Point(650, userTweet6Label.Location.Y + userTweet6Label.Height + 5);
            userTweet8Label.Location = new Point(650, userTweet7Label.Location.Y + userTweet7Label.Height + 5);
            userTweet9Label.Location = new Point(650, userTweet8Label.Location.Y + userTweet8Label.Height + 5);
            userTweet10Label.Location = new Point(650, userTweet9Label.Location.Y + userTweet9Label.Height + 5);
            userTweet11Label.Location = new Point(650, userTweet10Label.Location.Y + userTweet10Label.Height + 5);
            userTweet12Label.Location = new Point(650, userTweet11Label.Location.Y + userTweet11Label.Height + 5);
            userTweet13Label.Location = new Point(650, userTweet12Label.Location.Y + userTweet12Label.Height + 5);
            userTweet14Label.Location = new Point(650, userTweet13Label.Location.Y + userTweet13Label.Height + 5);
            userTweet15Label.Location = new Point(650, userTweet14Label.Location.Y + userTweet14Label.Height + 5);

            userTweet1Label.Visible = true;
            userTweet2Label.Visible = true;
            userTweet3Label.Visible = true;
            userTweet4Label.Visible = true;
            userTweet5Label.Visible = true;
            if (usersTweetUpDown.Value > 5)
                userTweet6Label.Visible = true;
            if (usersTweetUpDown.Value > 6)
                userTweet7Label.Visible = true;
            if (usersTweetUpDown.Value > 7)
                userTweet8Label.Visible = true;
            if (usersTweetUpDown.Value > 8)
                userTweet9Label.Visible = true;
            if (usersTweetUpDown.Value > 9)
                userTweet10Label.Visible = true;
            if (usersTweetUpDown.Value > 10)
                userTweet11Label.Visible = true;
            if (usersTweetUpDown.Value > 11)
                userTweet12Label.Visible = true;
            if (usersTweetUpDown.Value > 12)
                userTweet13Label.Visible = true;
            if (usersTweetUpDown.Value > 13)
                userTweet14Label.Visible = true;
            if (usersTweetUpDown.Value > 14)
                userTweet15Label.Visible = true;
        }

        private void ShowAllMentionTweetLabels()
        {
            mentionsTweet1Label.Location = new Point(650, 0);
            mentionsTweet2Label.Location = new Point(650, mentionsTweet1Label.Location.Y + mentionsTweet1Label.Height + 5);
            mentionsTweet3Label.Location = new Point(650, mentionsTweet2Label.Location.Y + mentionsTweet2Label.Height + 5);
            mentionsTweet4Label.Location = new Point(650, mentionsTweet3Label.Location.Y + mentionsTweet3Label.Height + 5);
            mentionsTweet5Label.Location = new Point(650, mentionsTweet4Label.Location.Y + mentionsTweet4Label.Height + 5);
            mentionsTweet6Label.Location = new Point(650, mentionsTweet5Label.Location.Y + mentionsTweet5Label.Height + 5);
            mentionsTweet7Label.Location = new Point(650, mentionsTweet6Label.Location.Y + mentionsTweet6Label.Height + 5);
            mentionsTweet8Label.Location = new Point(650, mentionsTweet7Label.Location.Y + mentionsTweet7Label.Height + 5);
            mentionsTweet9Label.Location = new Point(650, mentionsTweet8Label.Location.Y + mentionsTweet8Label.Height + 5);
            mentionsTweet10Label.Location = new Point(650, mentionsTweet9Label.Location.Y + mentionsTweet9Label.Height + 5);
            mentionsTweet11Label.Location = new Point(650, mentionsTweet10Label.Location.Y + mentionsTweet10Label.Height + 5);
            mentionsTweet12Label.Location = new Point(650, mentionsTweet11Label.Location.Y + mentionsTweet11Label.Height + 5);
            mentionsTweet13Label.Location = new Point(650, mentionsTweet12Label.Location.Y + mentionsTweet12Label.Height + 5);
            mentionsTweet14Label.Location = new Point(650, mentionsTweet13Label.Location.Y + mentionsTweet13Label.Height + 5);
            mentionsTweet15Label.Location = new Point(650, mentionsTweet14Label.Location.Y + mentionsTweet14Label.Height + 5);

            mentionsTweet1Label.Visible = true;
            mentionsTweet2Label.Visible = true;
            mentionsTweet3Label.Visible = true;
            mentionsTweet4Label.Visible = true;
            mentionsTweet5Label.Visible = true;
            if (mentionsTweetUpDown.Value > 5)
                mentionsTweet6Label.Visible = true;
            if (mentionsTweetUpDown.Value > 6)
                mentionsTweet7Label.Visible = true;
            if (mentionsTweetUpDown.Value > 7)
                mentionsTweet8Label.Visible = true;
            if (mentionsTweetUpDown.Value > 8)
                mentionsTweet9Label.Visible = true;
            if (mentionsTweetUpDown.Value > 9)
                mentionsTweet10Label.Visible = true;
            if (mentionsTweetUpDown.Value > 10)
                mentionsTweet11Label.Visible = true;
            if (mentionsTweetUpDown.Value > 11)
                mentionsTweet12Label.Visible = true;
            if (mentionsTweetUpDown.Value > 12)
                mentionsTweet13Label.Visible = true;
            if (mentionsTweetUpDown.Value > 13)
                mentionsTweet14Label.Visible = true;
            if (mentionsTweetUpDown.Value > 14)
                mentionsTweet15Label.Visible = true;
        }

        /***********************
        Name: ShowAllRetweetTweetLabels
        Purpose: Position and display all of the retweet labels

        Similar functions:
            ShowAllFavoriteTweetLabels
        ***********************/
        private void ShowAllRetweetTweetLabels()
        {
            //Set the location for each tweet label
            //They will all be veritically aligned
            //Each tweet's Y coordinate is calculated based on where the tweet above
            //it was positioned, the height of the tweet above it, and a little bit 
            //of extra space so things don't run together
            topRT1Label.Location = new Point(5, 5);
            topRT2Label.Location = new Point(5, topRT1Label.Location.Y + topRT1Label.Height + 5);
            topRT3Label.Location = new Point(5, topRT2Label.Location.Y + topRT2Label.Height + 5);
            topRT4Label.Location = new Point(5, topRT3Label.Location.Y + topRT3Label.Height + 5);
            topRT5Label.Location = new Point(5, topRT4Label.Location.Y + topRT4Label.Height + 5);
            topRT6Label.Location = new Point(5, topRT5Label.Location.Y + topRT5Label.Height + 5);
            topRT7Label.Location = new Point(5, topRT6Label.Location.Y + topRT6Label.Height + 5);
            topRT8Label.Location = new Point(5, topRT7Label.Location.Y + topRT7Label.Height + 5);
            topRT9Label.Location = new Point(5, topRT8Label.Location.Y + topRT8Label.Height + 5);
            topRT10Label.Location = new Point(5, topRT9Label.Location.Y + topRT9Label.Height + 5);
            topRT11Label.Location = new Point(5, topRT10Label.Location.Y + topRT10Label.Height + 5);
            topRT12Label.Location = new Point(5, topRT11Label.Location.Y + topRT11Label.Height + 5);
            topRT13Label.Location = new Point(5, topRT12Label.Location.Y + topRT12Label.Height + 5);
            topRT14Label.Location = new Point(5, topRT13Label.Location.Y + topRT13Label.Height + 5);
            topRT15Label.Location = new Point(5, topRT14Label.Location.Y + topRT14Label.Height + 5);
        }

        private void ShowAllFavoriteTweetLabels()
        {
            topFavorite1Label.Location = new Point(5, 5);
            topFavorite2Label.Location = new Point(5, topFavorite1Label.Location.Y + topFavorite1Label.Height + 5);
            topFavorite3Label.Location = new Point(5, topFavorite2Label.Location.Y + topFavorite1Label.Height + 5);
            topFavorite4Label.Location = new Point(5, topFavorite3Label.Location.Y + topFavorite2Label.Height + 5);
            topFavorite5Label.Location = new Point(5, topFavorite4Label.Location.Y + topFavorite3Label.Height + 5);
            topFavorite6Label.Location = new Point(5, topFavorite5Label.Location.Y + topFavorite4Label.Height + 5);
            topFavorite7Label.Location = new Point(5, topFavorite6Label.Location.Y + topFavorite5Label.Height + 5);
            topFavorite8Label.Location = new Point(5, topFavorite7Label.Location.Y + topFavorite6Label.Height + 5);
            topFavorite9Label.Location = new Point(5, topFavorite8Label.Location.Y + topFavorite7Label.Height + 5);
            topFavorite10Label.Location = new Point(5, topFavorite9Label.Location.Y + topFavorite9Label.Height + 5);
            topFavorite11Label.Location = new Point(5, topFavorite10Label.Location.Y + topFavorite10Label.Height + 5);
            topFavorite12Label.Location = new Point(5, topFavorite11Label.Location.Y + topFavorite11Label.Height + 5);
            topFavorite13Label.Location = new Point(5, topFavorite12Label.Location.Y + topFavorite12Label.Height + 5);
            topFavorite14Label.Location = new Point(5, topFavorite13Label.Location.Y + topFavorite13Label.Height + 5);
            topFavorite15Label.Location = new Point(5, topFavorite14Label.Location.Y + topFavorite14Label.Height + 5);
        }

        /***********************
        Name: SetWordTweetLabels
        Parameters: an array of tweets
        Purpose: Set all of the values for the tweet labels

        Similar functions:
            SetHashtagTweetLabels
            SetUserTweetLabels
            SetMentionTweetLabels
        ***********************/
        private void SetWordTweetLabels(tweet[] tweets)
        {
            //Set the text of the label to be the result of calling
            //the function ConvertTweetToLabel on the first tweet in the array
            wordTweet1Label.Text = ConvertTweetToLabel(tweets[0]);
            wordTweet2Label.Text = ConvertTweetToLabel(tweets[1]);
            wordTweet3Label.Text = ConvertTweetToLabel(tweets[2]);
            wordTweet4Label.Text = ConvertTweetToLabel(tweets[3]);
            wordTweet5Label.Text = ConvertTweetToLabel(tweets[4]);

            //Based on what the maximum of the wordsTweetUpDown is
            //Convert more tweets to text for labels
            if (wordsTweetUpDown.Maximum > 5)
                wordTweet6Label.Text = ConvertTweetToLabel(tweets[5]);
            if (wordsTweetUpDown.Maximum > 6)
                wordTweet7Label.Text = ConvertTweetToLabel(tweets[6]);
            if (wordsTweetUpDown.Maximum > 7)
                wordTweet8Label.Text = ConvertTweetToLabel(tweets[7]);
            if (wordsTweetUpDown.Maximum > 8)
                wordTweet9Label.Text = ConvertTweetToLabel(tweets[8]);
            if (wordsTweetUpDown.Maximum > 9)
                wordTweet10Label.Text = ConvertTweetToLabel(tweets[9]);
            if (wordsTweetUpDown.Maximum > 10)
                wordTweet11Label.Text = ConvertTweetToLabel(tweets[10]);
            if (wordsTweetUpDown.Maximum > 11)
                wordTweet12Label.Text = ConvertTweetToLabel(tweets[11]);
            if (wordsTweetUpDown.Maximum > 12)
                wordTweet13Label.Text = ConvertTweetToLabel(tweets[12]);
            if (wordsTweetUpDown.Maximum > 13)
                wordTweet14Label.Text = ConvertTweetToLabel(tweets[13]);
            if (wordsTweetUpDown.Maximum > 14)
                wordTweet15Label.Text = ConvertTweetToLabel(tweets[14]);
        }

        private void SetHashtagTweetLabels(tweet[] tweets)
        {
            hashtagTweet1Label.Text = ConvertTweetToLabel(tweets[0]);
            hashtagTweet2Label.Text = ConvertTweetToLabel(tweets[1]);
            hashtagTweet3Label.Text = ConvertTweetToLabel(tweets[2]);
            hashtagTweet4Label.Text = ConvertTweetToLabel(tweets[3]);
            hashtagTweet5Label.Text = ConvertTweetToLabel(tweets[4]);
            if (hashtagTweetUpDown.Maximum > 5)
                hashtagTweet6Label.Text = ConvertTweetToLabel(tweets[5]);
            if (hashtagTweetUpDown.Maximum > 6)
                hashtagTweet7Label.Text = ConvertTweetToLabel(tweets[6]);
            if (hashtagTweetUpDown.Maximum > 7)
                hashtagTweet8Label.Text = ConvertTweetToLabel(tweets[7]);
            if (hashtagTweetUpDown.Maximum > 8)
                hashtagTweet9Label.Text = ConvertTweetToLabel(tweets[8]);
            if (hashtagTweetUpDown.Maximum > 9)
                hashtagTweet10Label.Text = ConvertTweetToLabel(tweets[9]);
            if (hashtagTweetUpDown.Maximum > 10)
                hashtagTweet11Label.Text = ConvertTweetToLabel(tweets[10]);
            if (hashtagTweetUpDown.Maximum > 11)
                hashtagTweet12Label.Text = ConvertTweetToLabel(tweets[11]);
            if (hashtagTweetUpDown.Maximum > 12)
                hashtagTweet13Label.Text = ConvertTweetToLabel(tweets[12]);
            if (hashtagTweetUpDown.Maximum > 13)
                hashtagTweet14Label.Text = ConvertTweetToLabel(tweets[13]);
            if (hashtagTweetUpDown.Maximum > 14)
                hashtagTweet15Label.Text = ConvertTweetToLabel(tweets[14]);
        }

        private void SetUserTweetLabels(tweet[] tweets)
        {
            userTweet1Label.Text = ConvertTweetToLabel(tweets[0]);
            userTweet2Label.Text = ConvertTweetToLabel(tweets[1]);
            userTweet3Label.Text = ConvertTweetToLabel(tweets[2]);
            userTweet4Label.Text = ConvertTweetToLabel(tweets[3]);
            userTweet5Label.Text = ConvertTweetToLabel(tweets[4]);
            if (usersTweetUpDown.Maximum > 5)
                userTweet6Label.Text = ConvertTweetToLabel(tweets[5]);
            if (usersTweetUpDown.Maximum > 6)
                userTweet7Label.Text = ConvertTweetToLabel(tweets[6]);
            if (usersTweetUpDown.Maximum > 7)
                userTweet8Label.Text = ConvertTweetToLabel(tweets[7]);
            if (usersTweetUpDown.Maximum > 8)
                userTweet9Label.Text = ConvertTweetToLabel(tweets[8]);
            if (usersTweetUpDown.Maximum > 9)
                userTweet10Label.Text = ConvertTweetToLabel(tweets[9]);
            if (usersTweetUpDown.Maximum > 10)
                userTweet11Label.Text = ConvertTweetToLabel(tweets[10]);
            if (usersTweetUpDown.Maximum > 11)
                userTweet12Label.Text = ConvertTweetToLabel(tweets[11]);
            if (usersTweetUpDown.Maximum > 12)
                userTweet13Label.Text = ConvertTweetToLabel(tweets[12]);
            if (usersTweetUpDown.Maximum > 13)
                userTweet14Label.Text = ConvertTweetToLabel(tweets[13]);
            if (usersTweetUpDown.Maximum > 14)
                userTweet15Label.Text = ConvertTweetToLabel(tweets[14]);
        }

        private void SetMentionTweetLabels(tweet[] tweets)
        {
            mentionsTweet1Label.Text = ConvertTweetToLabel(tweets[0]);
            mentionsTweet2Label.Text = ConvertTweetToLabel(tweets[1]);
            mentionsTweet3Label.Text = ConvertTweetToLabel(tweets[2]);
            mentionsTweet4Label.Text = ConvertTweetToLabel(tweets[3]);
            mentionsTweet5Label.Text = ConvertTweetToLabel(tweets[4]);
            if (mentionsTweetUpDown.Maximum > 5)
                mentionsTweet6Label.Text = ConvertTweetToLabel(tweets[5]);
            if (mentionsTweetUpDown.Maximum > 6)
                mentionsTweet7Label.Text = ConvertTweetToLabel(tweets[6]);
            if (mentionsTweetUpDown.Maximum > 7)
                mentionsTweet8Label.Text = ConvertTweetToLabel(tweets[7]);
            if (mentionsTweetUpDown.Maximum > 8)
                mentionsTweet9Label.Text = ConvertTweetToLabel(tweets[8]);
            if (mentionsTweetUpDown.Maximum > 9)
                mentionsTweet10Label.Text = ConvertTweetToLabel(tweets[9]);
            if (mentionsTweetUpDown.Maximum > 10)
                mentionsTweet11Label.Text = ConvertTweetToLabel(tweets[10]);
            if (mentionsTweetUpDown.Maximum > 11)
                mentionsTweet12Label.Text = ConvertTweetToLabel(tweets[11]);
            if (mentionsTweetUpDown.Maximum > 12)
                mentionsTweet13Label.Text = ConvertTweetToLabel(tweets[12]);
            if (mentionsTweetUpDown.Maximum > 13)
                mentionsTweet14Label.Text = ConvertTweetToLabel(tweets[13]);
            if (mentionsTweetUpDown.Maximum > 14)
                mentionsTweet15Label.Text = ConvertTweetToLabel(tweets[14]);

        }

        /***********************
        Name: ShowWordLabels
        Purpose: Show the word labels in the blue circles

        Similar functions:
            ShowHashtagLabels
            ShowUserLabels
            ShowMentionsLabels
        ***********************/
        private void ShowWordLabels()
        {
            //We will always have to show the top five words
            topWord1Label.Visible = true;
            topWord2Label.Visible = true;
            topWord3Label.Visible = true;
            topWord4Label.Visible = true;
            topWord5Label.Visible = true;

            //Based on the value of the wordsUpDown, display
            //more words for the blue circles
            if (wordsUpDown.Value > 5)
                topWord6Label.Visible = true;
            if (wordsUpDown.Value > 6)
                topWord7Label.Visible = true;
            if (wordsUpDown.Value > 7)
                topWord8Label.Visible = true;
            if (wordsUpDown.Value > 8)
                topWord9Label.Visible = true;
            if (wordsUpDown.Value > 9)
                topWord10Label.Visible = true;
            if (wordsUpDown.Value > 10)
                topWord11Label.Visible = true;
            if (wordsUpDown.Value > 11)
                topWord12Label.Visible = true;
            if (wordsUpDown.Value > 12)
                topWord13Label.Visible = true;
            if (wordsUpDown.Value > 13)
                topWord14Label.Visible = true;
            if (wordsUpDown.Value > 14)
                topWord15Label.Visible = true;
        }

        private void ShowHashtagLabels()
        {
            topHashtag1Label.Visible = true;
            topHashtag2Label.Visible = true;
            topHashtag3Label.Visible = true;
            topHashtag4Label.Visible = true;
            topHashtag5Label.Visible = true;

            if (hashtagUpDown.Value > 5)
                topHashtag6Label.Visible = true;
            if (hashtagUpDown.Value > 6)
                topHashtag7Label.Visible = true;
            if (hashtagUpDown.Value > 7)
                topHashtag8Label.Visible = true;
            if (hashtagUpDown.Value > 8)
                topHashtag9Label.Visible = true;
            if (hashtagUpDown.Value > 9)
                topHashtag10Label.Visible = true;
            if (hashtagUpDown.Value > 10)
                topHashtag11Label.Visible = true;
            if (hashtagUpDown.Value > 11)
                topHashtag12Label.Visible = true;
            if (hashtagUpDown.Value > 12)
                topHashtag13Label.Visible = true;
            if (hashtagUpDown.Value > 13)
                topHashtag14Label.Visible = true;
            if (hashtagUpDown.Value > 14)
                topHashtag15Label.Visible = true;
        }

        private void ShowUserLabels()
        {
            topUser1Label.Visible = true;
            topUser2Label.Visible = true;
            topUser3Label.Visible = true;
            topUser4Label.Visible = true;
            topUser5Label.Visible = true;

            if (usersUpDown.Value > 5)
                topUser6Label.Visible = true;
            if (usersUpDown.Value > 6)
                topUser7Label.Visible = true;
            if (usersUpDown.Value > 7)
                topUser8Label.Visible = true;
            if (usersUpDown.Value > 8)
                topUser9Label.Visible = true;
            if (usersUpDown.Value > 9)
                topUser10Label.Visible = true;
            if (usersUpDown.Value > 10)
                topUser11Label.Visible = true;
            if (usersUpDown.Value > 11)
                topUser12Label.Visible = true;
            if (usersUpDown.Value > 12)
                topUser13Label.Visible = true;
            if (usersUpDown.Value > 13)
                topUser14Label.Visible = true;
            if (usersUpDown.Value > 14)
                topUser15Label.Visible = true;
        }

        private void ShowMentionLabels()
        {
            topMentions1Label.Visible = true;
            topMentions2Label.Visible = true;
            topMentions3Label.Visible = true;
            topMentions4Label.Visible = true;
            topMentions5Label.Visible = true;

            if (mentionsUpDown.Value > 5)
                topMentions6Label.Visible = true;
            if (mentionsUpDown.Value > 6)
                topMentions7Label.Visible = true;
            if (mentionsUpDown.Value > 7)
                topMentions8Label.Visible = true;
            if (mentionsUpDown.Value > 8)
                topMentions9Label.Visible = true;
            if (mentionsUpDown.Value > 9)
                topMentions10Label.Visible = true;
            if (mentionsUpDown.Value > 10)
                topMentions11Label.Visible = true;
            if (mentionsUpDown.Value > 11)
                topMentions12Label.Visible = true;
            if (mentionsUpDown.Value > 12)
                topMentions13Label.Visible = true;
            if (mentionsUpDown.Value > 13)
                topMentions14Label.Visible = true;
            if (mentionsUpDown.Value > 14)
                topMentions15Label.Visible = true;
        }
    }
}
